<?php
/**
* Theme Functions
*
* @package GridBone WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

/**
 * This function return a value of given theme option name from database.
 *
 * @since 1.0.0
 *
 * @param string $option Theme option to return.
 * @return mixed The value of theme option.
 */
function gridbone_get_option($option) {
    $gridbone_options = get_option('gridbone_options');
    if ((is_array($gridbone_options)) && (array_key_exists($option, $gridbone_options))) {
        return $gridbone_options[$option];
    }
    else {
        return '';
    }
}

function gridbone_is_option_set($option) {
    $gridbone_options = get_option('gridbone_options');
    if ((is_array($gridbone_options)) && (array_key_exists($option, $gridbone_options))) {
        return true;
    } else {
        return false;
    }
}

if ( ! function_exists( 'gridbone_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function gridbone_setup() {
    
    global $wp_version;

    /*
     * Make theme available for translation.
     * Translations can be filed in the /languages/ directory.
     * If you're building a theme based on GridBone, use a find and replace
     * to change 'gridbone' to the name of your theme in all the template files.
     */
    load_theme_textdomain( 'gridbone', get_template_directory() . '/languages' );

    // Add default posts and comments RSS feed links to head.
    add_theme_support( 'automatic-feed-links' );

    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support( 'title-tag' );

    /*
     * Enable support for Post Thumbnails on posts and pages.
     *
     * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
     */
    add_theme_support( 'post-thumbnails' );

    if ( function_exists( 'add_image_size' ) ) {
        add_image_size( 'gridbone-1200w-autoh-image', 1200, 9999, false );
        add_image_size( 'gridbone-872w-autoh-image', 872, 9999, false );
        add_image_size( 'gridbone-480w-480h-image', 480, 480, true );
        add_image_size( 'gridbone-480w-360h-image', 480, 360, true );
        add_image_size( 'gridbone-125w-125h-image', 125, 125, true );
    }

    // This theme uses wp_nav_menu() in one location.
    register_nav_menus( array(
    'primary' => esc_html__('Primary Menu', 'gridbone'),
    'secondary' => esc_html__('Secondary Menu', 'gridbone')
    ) );

    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    $markup = array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption', 'navigation-widgets' );
    add_theme_support( 'html5', $markup );

    add_theme_support( 'custom-logo', array(
        'height'      => 37,
        'width'       => 280,
        'flex-height' => true,
        'flex-width'  => true,
        'header-text' => array( 'site-title', 'site-description' ),
    ) );

    // Support for Custom Header
    add_theme_support( 'custom-header', apply_filters( 'gridbone_custom_header_args', array(
    'default-image'          => '',
    'default-text-color'     => 'ffffff',
    'width'                  => 1920,
    'height'                 => 400,
    'flex-width'            => true,
    'flex-height'            => true,
    'wp-head-callback'       => 'gridbone_header_style',
    'uploads'                => true,
    ) ) );

    // Set up the WordPress core custom background feature.
    $background_args = array(
            'default-color'          => 'eeeeee',
            'default-image'          => '',
            'default-repeat'         => 'repeat',
            'default-position-x'     => 'left',
            'default-position-y'     => 'top',
            'default-size'     => 'auto',
            'default-attachment'     => 'fixed',
            'wp-head-callback'       => '_custom_background_cb',
            'admin-head-callback'    => 'admin_head_callback_func',
            'admin-preview-callback' => 'admin_preview_callback_func',
    );
    add_theme_support( 'custom-background', apply_filters( 'gridbone_custom_background_args', $background_args) );
    
    // Support for Custom Editor Style
    add_editor_style( 'assets/css/editor-style.css' );

    // Add support for responsive embedded content.
    add_theme_support( 'responsive-embeds' );

    // Add support for Block Styles.
    add_theme_support( 'wp-block-styles' );

    add_theme_support( 'woocommerce' );

    add_theme_support( 'wc-product-gallery-zoom' );
    add_theme_support( 'wc-product-gallery-lightbox' );
    add_theme_support( 'wc-product-gallery-slider' );

    add_theme_support( 'yoast-seo-breadcrumbs' );

    if ( !(gridbone_get_option('enable_widgets_block_editor')) ) {
        remove_theme_support( 'widgets-block-editor' );
    }

}
endif;
add_action( 'after_setup_theme', 'gridbone_setup' );


/**
* Layout Functions
*/

function gridbone_hide_footer_widgets() {
    $hide_footer_widgets = false;

    if ( gridbone_get_option('hide_footer_widgets') ) {
        $hide_footer_widgets = true;
    }

    return apply_filters( 'gridbone_hide_footer_widgets', $hide_footer_widgets );
}

function gridbone_is_header_content_active() {
    $header_content_active = true;

    if ( gridbone_get_option('hide_header_content') ) {
        $header_content_active = false;
    }

    return apply_filters( 'gridbone_is_header_content_active', $header_content_active );
}

function gridbone_is_primary_menu_active() {
    $primary_menu_active = true;

    if ( gridbone_get_option('disable_primary_menu') ) {
        $primary_menu_active = false;
    }

    return apply_filters( 'gridbone_is_primary_menu_active', $primary_menu_active );
}

function gridbone_is_secondary_menu_active() {
    $secondary_menu_active = true;

    if ( gridbone_get_option('disable_secondary_menu') ) {
        $secondary_menu_active = false;
    }

    return apply_filters( 'gridbone_is_secondary_menu_active', $secondary_menu_active );
}

function gridbone_is_sticky_menu_active() {
    $sticky_menu_active = true;

    if ( gridbone_get_option('disable_sticky_menu') ) {
        $sticky_menu_active = false;
    }

    return apply_filters( 'gridbone_is_sticky_menu_active', $sticky_menu_active );
}

function gridbone_is_sticky_mobile_menu_active() {
    $sticky_mobile_menu_active = false;

    if ( gridbone_get_option('enable_sticky_mobile_menu') ) {
        $sticky_mobile_menu_active = true;
    }

    return apply_filters( 'gridbone_is_sticky_mobile_menu_active', $sticky_mobile_menu_active );
}

function gridbone_is_social_buttons_active() {
    $social_buttons_active = true;

    if ( gridbone_get_option('hide_social_buttons') ) {
        $social_buttons_active = false;
    }

    return apply_filters( 'gridbone_is_social_buttons_active', $social_buttons_active );
}

function gridbone_is_sticky_sidebar_active() {
    $sticky_sidebar_active = true;

    if ( gridbone_get_option('disable_sticky_sidebar') ) {
        $sticky_sidebar_active = false;
    }

    return apply_filters( 'gridbone_is_sticky_sidebar_active', $sticky_sidebar_active );
}

function gridbone_is_fitvids_active() {
    $fitvids_active = true;

    if ( gridbone_get_option('disable_fitvids') ) {
        $fitvids_active = false;
    }

    return apply_filters( 'gridbone_is_fitvids_active', $fitvids_active );
}

function gridbone_is_backtotop_active() {
    $backtotop_active = true;

    if ( gridbone_get_option('disable_backtotop') ) {
        $backtotop_active = false;
    }

    return apply_filters( 'gridbone_is_backtotop_active', $backtotop_active );
}

function gridbone_grid_item_border_radius() {
    $grid_item_border_radius = '0px';
    if ( gridbone_get_option('grid_item_border_radius') ) {
        $grid_item_border_radius = gridbone_get_option('grid_item_border_radius');
    }

   return apply_filters( 'gridbone_grid_item_border_radius', $grid_item_border_radius );
}

function gridbone_is_header_content_image_active() {
    $header_content_image_active = false;
    $header_image_id = 0;

    if ( gridbone_get_option('header_content_image') ) {
        $header_image_id = absint(gridbone_get_option('header_content_image'));
    }

    if ( $header_image_id > 0 ) {
        $header_content_image_active = true;
    }

    return apply_filters( 'gridbone_is_header_content_image_active', $header_content_image_active );
}

function gridbone_is_footer_content_image_active() {
    $footer_content_image_active = false;
    $footer_image_id = 0;

    if ( gridbone_get_option('footer_content_image') ) {
        $footer_image_id = absint(gridbone_get_option('footer_content_image'));
    }

    if ( $footer_image_id > 0 ) {
        $footer_content_image_active = true;
    }

    return apply_filters( 'gridbone_is_footer_content_image_active', $footer_content_image_active );
}

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function gridbone_content_width() {
    $content_width = 924;

    if ( is_singular() ) {
        if ( is_page_template( array( 'template-full-width-page.php', 'template-full-width-post.php' ) ) ) {
           $content_width = 1322;
        } else {
            $content_width = 924;
        }
    } else {
        $content_width = 1322;
    }

    $GLOBALS['content_width'] = apply_filters( 'gridbone_content_width', $content_width ); /* phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound */
}
add_action( 'template_redirect', 'gridbone_content_width', 0 );

function gridbone_grid_thumb_position() {
   $thumb_position = 'top';
    if ( gridbone_get_option('grid_thumb_position') ) {
        $thumb_position = gridbone_get_option('grid_thumb_position');
    }
    return apply_filters( 'gridbone_grid_thumb_position', $thumb_position );
}

function gridbone_grid_title_style() {
   $title_style = 'always-show';
    if ( gridbone_get_option('grid_title_style') ) {
        $title_style = gridbone_get_option('grid_title_style');
    }
    return apply_filters( 'gridbone_grid_title_style', $title_style );
}


/**
* Register widget area.
*
* @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
*/

function gridbone_widgets_init() {

register_sidebar(array(
    'id' => 'gridbone-sidebar-one',
    'name' => esc_html__( 'Sidebar 1 Widgets', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located on the left-hand side of your web page.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-side-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-home-fullwidth-widgets',
    'name' => esc_html__( 'Top Full Width Widgets (Default HomePage)', 'gridbone' ),
    'description' => esc_html__( 'This full-width widget area is located after the header of your website. Widgets of this widget area are displayed on the default homepage of your website (when you are showing your latest posts on homepage).', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-fullwidth-widgets',
    'name' => esc_html__( 'Top Full Width Widgets (Everywhere)', 'gridbone' ),
    'description' => esc_html__( 'This full-width widget area is located after the header of your website. Widgets of this widget area are displayed on every page of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-home-top-widgets',
    'name' => esc_html__( 'Above Content Widgets (Default HomePage)', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located at the top of the main content (above posts) of your website. Widgets of this widget area are displayed on the default homepage of your website (when you are showing your latest posts on homepage).', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-top-widgets',
    'name' => esc_html__( 'Above Content Widgets (Everywhere)', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located at the top of the main content (above posts) of your website. Widgets of this widget area are displayed on every page of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-home-left-top-widgets',
    'name' => esc_html__( 'Top Left Widgets (Default HomePage)', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located at the left top of your website. Widgets of this widget area are displayed on the default homepage of your website (when you are showing your latest posts on homepage).', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-left-top-widgets',
    'name' => esc_html__( 'Top Left Widgets (Everywhere)', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located at the left top of your website. Widgets of this widget area are displayed on every page of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-home-right-top-widgets',
    'name' => esc_html__( 'Top Right Widgets (Default HomePage)', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located at the right top of your website. Widgets of this widget area are displayed on the default homepage of your website (when you are showing your latest posts on homepage).', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-right-top-widgets',
    'name' => esc_html__( 'Top Right Widgets (Everywhere)', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located at the right top of your website. Widgets of this widget area are displayed on every page of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-home-bottom-widgets',
    'name' => esc_html__( 'Below Content Widgets (Default HomePage)', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located at the bottom of the main content (below posts) of your website. Widgets of this widget area are displayed on the default homepage of your website (when you are showing your latest posts on homepage).', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-bottom-widgets',
    'name' => esc_html__( 'Below Content Widgets (Everywhere)', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located at the bottom of the main content (below posts) of your website. Widgets of this widget area are displayed on every page of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-home-fullwidth-bottom-widgets',
    'name' => esc_html__( 'Bottom Full Width Widgets (Default HomePage)', 'gridbone' ),
    'description' => esc_html__( 'This full-width widget area is located before the footer of your website. Widgets of this widget area are displayed on the default homepage of your website (when you are showing your latest posts on homepage).', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-fullwidth-bottom-widgets',
    'name' => esc_html__( 'Bottom Full Width Widgets (Everywhere)', 'gridbone' ),
    'description' => esc_html__( 'This full-width widget area is located before the footer of your website. Widgets of this widget area are displayed on every page of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-single-post-bottom-widgets',
    'name' => esc_html__( 'Single Post Bottom Widgets', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located at the bottom of single post of any post type (except attachments and pages).', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

register_sidebar(array(
    'id' => 'gridbone-top-footer',
    'name' => esc_html__( 'Footer Top Widgets', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located on the top of the footer of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-footer-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2>'));

register_sidebar(array(
    'id' => 'gridbone-footer-1',
    'name' => esc_html__( 'Footer 1 Widgets', 'gridbone' ),
    'description' => esc_html__( 'This widget area is the column 1 of the footer of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-footer-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2>'));

register_sidebar(array(
    'id' => 'gridbone-footer-2',
    'name' => esc_html__( 'Footer 2 Widgets', 'gridbone' ),
    'description' => esc_html__( 'This widget area is the column 2 of the footer of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-footer-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2>'));

register_sidebar(array(
    'id' => 'gridbone-footer-3',
    'name' => esc_html__( 'Footer 3 Widgets', 'gridbone' ),
    'description' => esc_html__( 'This widget area is the column 3 of the footer of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-footer-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2>'));

register_sidebar(array(
    'id' => 'gridbone-footer-4',
    'name' => esc_html__( 'Footer 4 Widgets', 'gridbone' ),
    'description' => esc_html__( 'This widget area is the column 4 of the footer of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-footer-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2>'));

register_sidebar(array(
    'id' => 'gridbone-footer-5',
    'name' => esc_html__( 'Footer 5 Widgets', 'gridbone' ),
    'description' => esc_html__( 'This widget area is the column 5 of the footer of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-footer-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2>'));

register_sidebar(array(
    'id' => 'gridbone-bottom-footer',
    'name' => esc_html__( 'Footer Bottom Widgets', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located on the bottom of the footer of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-footer-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2>'));

register_sidebar(array(
    'id' => 'gridbone-404-widgets',
    'name' => esc_html__( '404 Page Widgets', 'gridbone' ),
    'description' => esc_html__( 'This widget area is located on the 404(not found) page of your website.', 'gridbone' ),
    'before_widget' => '<div id="%1$s" class="gridbone-main-widget widget gridbone-widget-box %2$s"><div class="gridbone-widget-box-inside">',
    'after_widget' => '</div></div>',
    'before_title' => '<div class="gridbone-widget-header"><h2 class="gridbone-widget-title"><span class="gridbone-widget-title-inside">',
    'after_title' => '</span></h2></div>'));

}
add_action( 'widgets_init', 'gridbone_widgets_init' );


function gridbone_sidebar_one_widgets() {
    dynamic_sidebar( 'gridbone-sidebar-one' );
}

function gridbone_top_wide_widgets() { ?>

<?php if ( is_active_sidebar( 'gridbone-home-fullwidth-widgets' ) || is_active_sidebar( 'gridbone-fullwidth-widgets' ) ) : ?>
<div class="gridbone-top-wrapper-outer gridbone-clearfix">
<div class="gridbone-featured-posts-area gridbone-top-wrapper gridbone-clearfix">
<?php if ( is_front_page() && is_home() && !is_paged() ) { ?>
<?php dynamic_sidebar( 'gridbone-home-fullwidth-widgets' ); ?>
<?php } ?>

<?php dynamic_sidebar( 'gridbone-fullwidth-widgets' ); ?>
</div>
</div>
<?php endif; ?>

<?php }


function gridbone_top_widgets() { ?>

<?php if ( is_active_sidebar( 'gridbone-home-top-widgets' ) || is_active_sidebar( 'gridbone-top-widgets' ) ) : ?>
<div class="gridbone-featured-posts-area gridbone-featured-posts-area-top gridbone-clearfix">
<?php if ( is_front_page() && is_home() && !is_paged() ) { ?>
<?php dynamic_sidebar( 'gridbone-home-top-widgets' ); ?>
<?php } ?>

<?php dynamic_sidebar( 'gridbone-top-widgets' ); ?>
</div>
<?php endif; ?>

<?php }


function gridbone_top_left_right_widgets() { ?>

<div class="gridbone-left-right-wrapper gridbone-clearfix">

<?php if ( is_active_sidebar( 'gridbone-home-left-top-widgets' ) || is_active_sidebar( 'gridbone-left-top-widgets' ) ) : ?>
<div class="gridbone-left-top-wrapper">
<div class="gridbone-featured-posts-area gridbone-featured-posts-area-top gridbone-clearfix">
<?php if ( is_front_page() && is_home() && !is_paged() ) { ?>
<?php dynamic_sidebar( 'gridbone-home-left-top-widgets' ); ?>
<?php } ?>

<?php dynamic_sidebar( 'gridbone-left-top-widgets' ); ?>
</div>
</div>
<?php endif; ?>

<?php if ( is_active_sidebar( 'gridbone-home-right-top-widgets' ) || is_active_sidebar( 'gridbone-right-top-widgets' ) ) : ?>
<div class="gridbone-right-top-wrapper">
<div class="gridbone-featured-posts-area gridbone-featured-posts-area-top gridbone-clearfix">
<?php if ( is_front_page() && is_home() && !is_paged() ) { ?>
<?php dynamic_sidebar( 'gridbone-home-right-top-widgets' ); ?>
<?php } ?>

<?php dynamic_sidebar( 'gridbone-right-top-widgets' ); ?>
</div>
</div>
<?php endif; ?>

</div>

<?php }


function gridbone_bottom_widgets() { ?>

<?php if ( is_active_sidebar( 'gridbone-home-bottom-widgets' ) || is_active_sidebar( 'gridbone-bottom-widgets' ) ) : ?>
<div class='gridbone-featured-posts-area gridbone-featured-posts-area-bottom gridbone-clearfix'>
<?php if ( is_front_page() && is_home() && !is_paged() ) { ?>
<?php dynamic_sidebar( 'gridbone-home-bottom-widgets' ); ?>
<?php } ?>

<?php dynamic_sidebar( 'gridbone-bottom-widgets' ); ?>
</div>
<?php endif; ?>

<?php }


function gridbone_bottom_wide_widgets() { ?>

<?php if ( is_active_sidebar( 'gridbone-home-fullwidth-bottom-widgets' ) || is_active_sidebar( 'gridbone-fullwidth-bottom-widgets' ) ) : ?>
<div class="gridbone-outer-wrapper">
<div class="gridbone-bottom-wrapper-outer gridbone-clearfix">
<div class="gridbone-featured-posts-area gridbone-bottom-wrapper gridbone-clearfix">
<?php if ( is_front_page() && is_home() && !is_paged() ) { ?>
<?php dynamic_sidebar( 'gridbone-home-fullwidth-bottom-widgets' ); ?>
<?php } ?>

<?php dynamic_sidebar( 'gridbone-fullwidth-bottom-widgets' ); ?>
</div>
</div>
</div>
<?php endif; ?>

<?php }

function gridbone_404_widgets() { ?>

<?php if ( is_active_sidebar( 'gridbone-404-widgets' ) ) : ?>
<div class="gridbone-featured-posts-area gridbone-featured-posts-area-top gridbone-clearfix">
<?php dynamic_sidebar( 'gridbone-404-widgets' ); ?>
</div>
<?php endif; ?>

<?php }

function gridbone_post_bottom_widgets() {
    if ( is_singular() ) {
        if ( is_active_sidebar( 'gridbone-single-post-bottom-widgets' ) ) : ?>
            <div class="gridbone-featured-posts-area gridbone-clearfix">
            <?php dynamic_sidebar( 'gridbone-single-post-bottom-widgets' ); ?>
            </div>
        <?php endif;
    }
}


/**
* Post share buttons
*/

function gridbone_share_text() {
    $sharetext = esc_html__( 'Share:', 'gridbone' );
    if ( gridbone_get_option('hide_share_text') ) {return;}
    if ( gridbone_get_option('share_text') ) {
        $sharetext = gridbone_get_option('share_text');
    }
    return apply_filters( 'gridbone_share_text', $sharetext );
}

function gridbone_social_sharing_buttons() {

    global $post;

    // Get current page URL 
    $posturl = rawurlencode(get_permalink($post->ID));

    // Get current page title
    $posttitle = the_title_attribute('echo=0');
    $posttitle = !empty($posttitle) ? rawurlencode($posttitle) : '';

    // Construct sharing URL without using any script
    $x_url = 'https://x.com/intent/post?text='.$posttitle.'&amp;url='.$posturl;
    $facebook_url = 'https://www.facebook.com/sharer.php?u='.$posturl;
    $linkedin_url = 'https://www.linkedin.com/shareArticle?mini=true&amp;title='.$posttitle.'&amp;url='.$posturl;

    $postthumb = '';
    $postthumb_attributes = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full', false );
    $postthumb = isset($postthumb_attributes[0]) ? $postthumb_attributes[0] : '';

    if(!empty($postthumb)) {
        $pinterest_url = 'https://pinterest.com/pin/create/button/?url='.$posturl.'&amp;media='.$postthumb.'&amp;description='.$posttitle;
    }

    // Add sharing button at the end of page/page content
    $socialcontent = '<div class="gridbone-share-buttons gridbone-clearfix"><span class="gridbone-share-text">'.esc_html(gridbone_share_text()).' </span>';
    if ( !(gridbone_get_option('hide_share_twitter')) ) {
        $socialcontent .= '<a class="gridbone-share-buttons-twitter" href="'.esc_url($x_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on X', 'gridbone').'"><i class="fab fa-x-twitter" aria-hidden="true"></i><span class="gridbone-share-buttons-text">'.esc_html__('X', 'gridbone').'</span></a>';
    }
    if ( !(gridbone_get_option('hide_share_facebook')) ) {
        $socialcontent .= '<a class="gridbone-share-buttons-facebook" href="'.esc_url($facebook_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Facebook', 'gridbone').'"><i class="fab fa-facebook-f" aria-hidden="true"></i><span class="gridbone-share-buttons-text">'.esc_html__('Facebook', 'gridbone').'</span></a>';
    }
    if ( !(gridbone_get_option('hide_share_pinterest')) && !(empty($postthumb)) ) {
        $socialcontent .= '<a class="gridbone-share-buttons-pinterest" href="'.esc_url($pinterest_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Pinterest', 'gridbone').'"><i class="fab fa-pinterest" aria-hidden="true"></i><span class="gridbone-share-buttons-text">'.esc_html__('Pinterest', 'gridbone').'</span></a>';
    }
    if ( !(gridbone_get_option('hide_share_linkedin')) ) {
        $socialcontent .= '<a class="gridbone-share-buttons-linkedin" href="'.esc_url($linkedin_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Linkedin', 'gridbone').'"><i class="fab fa-linkedin-in" aria-hidden="true"></i><span class="gridbone-share-buttons-text">'.esc_html__('Linkedin', 'gridbone').'</span></a>';
    }
    $socialcontent .= '</div>';

    return apply_filters( 'gridbone_social_sharing_buttons', $socialcontent );

}


/**
* Social buttons
*/

function gridbone_social_buttons() { ?>

<div class='gridbone-social-icons'>
    <?php if ( gridbone_get_option('twitterlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('twitterlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-twitter" aria-label="<?php esc_attr_e('X Button','gridbone'); ?>"><i class="fab fa-x-twitter" aria-hidden="true" title="<?php esc_attr_e('X','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('facebooklink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('facebooklink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-facebook" aria-label="<?php esc_attr_e('Facebook Button','gridbone'); ?>"><i class="fab fa-facebook-f" aria-hidden="true" title="<?php esc_attr_e('Facebook','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('threadslink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('threadslink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-threads" aria-label="<?php esc_attr_e('Threads Button','gridbone'); ?>"><i class="fab fa-threads" aria-hidden="true" title="<?php esc_attr_e('Threads','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('pinterestlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('pinterestlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-pinterest" aria-label="<?php esc_attr_e('Pinterest Button','gridbone'); ?>"><i class="fab fa-pinterest" aria-hidden="true" title="<?php esc_attr_e('Pinterest','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('linkedinlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('linkedinlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-linkedin" aria-label="<?php esc_attr_e('Linkedin Button','gridbone'); ?>"><i class="fab fa-linkedin-in" aria-hidden="true" title="<?php esc_attr_e('Linkedin','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('instagramlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('instagramlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-instagram" aria-label="<?php esc_attr_e('Instagram Button','gridbone'); ?>"><i class="fab fa-instagram" aria-hidden="true" title="<?php esc_attr_e('Instagram','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('flickrlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('flickrlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-flickr" aria-label="<?php esc_attr_e('Flickr Button','gridbone'); ?>"><i class="fab fa-flickr" aria-hidden="true" title="<?php esc_attr_e('Flickr','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('youtubelink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('youtubelink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-youtube" aria-label="<?php esc_attr_e('Youtube Button','gridbone'); ?>"><i class="fab fa-youtube" aria-hidden="true" title="<?php esc_attr_e('Youtube','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('vimeolink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('vimeolink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-vimeo" aria-label="<?php esc_attr_e('Vimeo Button','gridbone'); ?>"><i class="fab fa-vimeo-v" aria-hidden="true" title="<?php esc_attr_e('Vimeo','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('soundcloudlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('soundcloudlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-soundcloud" aria-label="<?php esc_attr_e('SoundCloud Button','gridbone'); ?>"><i class="fab fa-soundcloud" aria-hidden="true" title="<?php esc_attr_e('SoundCloud','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('messengerlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('messengerlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-messenger" aria-label="<?php esc_attr_e('Messenger Button','gridbone'); ?>"><i class="fab fa-facebook-messenger" aria-hidden="true" title="<?php esc_attr_e('Messenger','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('whatsapplink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('whatsapplink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-whatsapp" aria-label="<?php esc_attr_e('WhatsApp Button','gridbone'); ?>"><i class="fab fa-whatsapp" aria-hidden="true" title="<?php esc_attr_e('WhatsApp','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('tiktoklink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('tiktoklink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-tiktok" aria-label="<?php esc_attr_e('TikTok Button','gridbone'); ?>"><i class="fab fa-tiktok" aria-hidden="true" title="<?php esc_attr_e('TikTok','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('lastfmlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('lastfmlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-lastfm" aria-label="<?php esc_attr_e('Lastfm Button','gridbone'); ?>"><i class="fab fa-lastfm" aria-hidden="true" title="<?php esc_attr_e('Lastfm','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('mediumlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('mediumlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-medium" aria-label="<?php esc_attr_e('Medium Button','gridbone'); ?>"><i class="fab fa-medium-m" aria-hidden="true" title="<?php esc_attr_e('Medium','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('githublink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('githublink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-github" aria-label="<?php esc_attr_e('Github Button','gridbone'); ?>"><i class="fab fa-github" aria-hidden="true" title="<?php esc_attr_e('Github','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('bitbucketlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('bitbucketlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-bitbucket" aria-label="<?php esc_attr_e('Bitbucket Button','gridbone'); ?>"><i class="fab fa-bitbucket" aria-hidden="true" title="<?php esc_attr_e('Bitbucket','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('tumblrlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('tumblrlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-tumblr" aria-label="<?php esc_attr_e('Tumblr Button','gridbone'); ?>"><i class="fab fa-tumblr" aria-hidden="true" title="<?php esc_attr_e('Tumblr','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('digglink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('digglink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-digg" aria-label="<?php esc_attr_e('Digg Button','gridbone'); ?>"><i class="fab fa-digg" aria-hidden="true" title="<?php esc_attr_e('Digg','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('deliciouslink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('deliciouslink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-delicious" aria-label="<?php esc_attr_e('Delicious Button','gridbone'); ?>"><i class="fab fa-delicious" aria-hidden="true" title="<?php esc_attr_e('Delicious','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('stumblelink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('stumblelink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-stumbleupon" aria-label="<?php esc_attr_e('Stumbleupon Button','gridbone'); ?>"><i class="fab fa-stumbleupon" aria-hidden="true" title="<?php esc_attr_e('Stumbleupon','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('mixlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('mixlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-mix" aria-label="<?php esc_attr_e('Mix Button','gridbone'); ?>"><i class="fab fa-mix" aria-hidden="true" title="<?php esc_attr_e('Mix','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('redditlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('redditlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-reddit" aria-label="<?php esc_attr_e('Reddit Button','gridbone'); ?>"><i class="fab fa-reddit" aria-hidden="true" title="<?php esc_attr_e('Reddit','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('dribbblelink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('dribbblelink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-dribbble" aria-label="<?php esc_attr_e('Dribbble Button','gridbone'); ?>"><i class="fab fa-dribbble" aria-hidden="true" title="<?php esc_attr_e('Dribbble','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('flipboardlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('flipboardlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-flipboard" aria-label="<?php esc_attr_e('Flipboard Button','gridbone'); ?>"><i class="fab fa-flipboard" aria-hidden="true" title="<?php esc_attr_e('Flipboard','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('bloggerlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('bloggerlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-blogger" aria-label="<?php esc_attr_e('Blogger Button','gridbone'); ?>"><i class="fab fa-blogger" aria-hidden="true" title="<?php esc_attr_e('Blogger','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('etsylink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('etsylink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-etsy" aria-label="<?php esc_attr_e('Etsy Button','gridbone'); ?>"><i class="fab fa-etsy" aria-hidden="true" title="<?php esc_attr_e('Etsy','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('behancelink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('behancelink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-behance" aria-label="<?php esc_attr_e('Behance Button','gridbone'); ?>"><i class="fab fa-behance" aria-hidden="true" title="<?php esc_attr_e('Behance','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('amazonlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('amazonlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-amazon" aria-label="<?php esc_attr_e('Amazon Button','gridbone'); ?>"><i class="fab fa-amazon" aria-hidden="true" title="<?php esc_attr_e('Amazon','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('meetuplink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('meetuplink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-meetup" aria-label="<?php esc_attr_e('Meetup Button','gridbone'); ?>"><i class="fab fa-meetup" aria-hidden="true" title="<?php esc_attr_e('Meetup','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('mixcloudlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('mixcloudlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-mixcloud" aria-label="<?php esc_attr_e('Mixcloud Button','gridbone'); ?>"><i class="fab fa-mixcloud" aria-hidden="true" title="<?php esc_attr_e('Mixcloud','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('slacklink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('slacklink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-slack" aria-label="<?php esc_attr_e('Slack Button','gridbone'); ?>"><i class="fab fa-slack" aria-hidden="true" title="<?php esc_attr_e('Slack','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('snapchatlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('snapchatlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-snapchat" aria-label="<?php esc_attr_e('Snapchat Button','gridbone'); ?>"><i class="fab fa-snapchat" aria-hidden="true" title="<?php esc_attr_e('Snapchat','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('spotifylink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('spotifylink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-spotify" aria-label="<?php esc_attr_e('Spotify Button','gridbone'); ?>"><i class="fab fa-spotify" aria-hidden="true" title="<?php esc_attr_e('Spotify','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('yelplink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('yelplink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-yelp" aria-label="<?php esc_attr_e('Yelp Button','gridbone'); ?>"><i class="fab fa-yelp" aria-hidden="true" title="<?php esc_attr_e('Yelp','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('wordpresslink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('wordpresslink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-wordpress" aria-label="<?php esc_attr_e('WordPress Button','gridbone'); ?>"><i class="fab fa-wordpress" aria-hidden="true" title="<?php esc_attr_e('WordPress','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('twitchlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('twitchlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-twitch" aria-label="<?php esc_attr_e('Twitch Button','gridbone'); ?>"><i class="fab fa-twitch" aria-hidden="true" title="<?php esc_attr_e('Twitch','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('telegramlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('telegramlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-telegram" aria-label="<?php esc_attr_e('Telegram Button','gridbone'); ?>"><i class="fab fa-telegram" aria-hidden="true" title="<?php esc_attr_e('Telegram','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('bandcamplink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('bandcamplink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-bandcamp" aria-label="<?php esc_attr_e('Bandcamp Button','gridbone'); ?>"><i class="fab fa-bandcamp" aria-hidden="true" title="<?php esc_attr_e('Bandcamp','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('quoralink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('quoralink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-quora" aria-label="<?php esc_attr_e('Quora Button','gridbone'); ?>"><i class="fab fa-quora" aria-hidden="true" title="<?php esc_attr_e('Quora','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('foursquarelink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('foursquarelink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-foursquare" aria-label="<?php esc_attr_e('Foursquare Button','gridbone'); ?>"><i class="fab fa-foursquare" aria-hidden="true" title="<?php esc_attr_e('Foursquare','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('deviantartlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('deviantartlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-deviantart" aria-label="<?php esc_attr_e('DeviantArt Button','gridbone'); ?>"><i class="fab fa-deviantart" aria-hidden="true" title="<?php esc_attr_e('DeviantArt','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('imdblink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('imdblink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-imdb" aria-label="<?php esc_attr_e('IMDB Button','gridbone'); ?>"><i class="fab fa-imdb" aria-hidden="true" title="<?php esc_attr_e('IMDB','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('vklink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('vklink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-vk" aria-label="<?php esc_attr_e('VK Button','gridbone'); ?>"><i class="fab fa-vk" aria-hidden="true" title="<?php esc_attr_e('VK','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('codepenlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('codepenlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-codepen" aria-label="<?php esc_attr_e('Codepen Button','gridbone'); ?>"><i class="fab fa-codepen" aria-hidden="true" title="<?php esc_attr_e('Codepen','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('jsfiddlelink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('jsfiddlelink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-jsfiddle" aria-label="<?php esc_attr_e('JSFiddle Button','gridbone'); ?>"><i class="fab fa-jsfiddle" aria-hidden="true" title="<?php esc_attr_e('JSFiddle','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('stackoverflowlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('stackoverflowlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-stackoverflow" aria-label="<?php esc_attr_e('Stack Overflow Button','gridbone'); ?>"><i class="fab fa-stack-overflow" aria-hidden="true" title="<?php esc_attr_e('Stack Overflow','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('stackexchangelink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('stackexchangelink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-stackexchange" aria-label="<?php esc_attr_e('Stack Exchange Button','gridbone'); ?>"><i class="fab fa-stack-exchange" aria-hidden="true" title="<?php esc_attr_e('Stack Exchange','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('bsalink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('bsalink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-buysellads" aria-label="<?php esc_attr_e('BuySellAds Button','gridbone'); ?>"><i class="fab fa-buysellads" aria-hidden="true" title="<?php esc_attr_e('BuySellAds','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('web500pxlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('web500pxlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-web500px" aria-label="<?php esc_attr_e('500px Button','gridbone'); ?>"><i class="fab fa-500px" aria-hidden="true" title="<?php esc_attr_e('500px','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('ellolink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('ellolink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-ello" aria-label="<?php esc_attr_e('Ello Button','gridbone'); ?>"><i class="fab fa-ello" aria-hidden="true" title="<?php esc_attr_e('Ello','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('discordlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('discordlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-discord" aria-label="<?php esc_attr_e('Discord Button','gridbone'); ?>"><i class="fab fa-discord" aria-hidden="true" title="<?php esc_attr_e('Discord','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('goodreadslink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('goodreadslink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-goodreads" aria-label="<?php esc_attr_e('Goodreads Button','gridbone'); ?>"><i class="fab fa-goodreads" aria-hidden="true" title="<?php esc_attr_e('Goodreads','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('odnoklassnikilink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('odnoklassnikilink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-odnoklassniki" aria-label="<?php esc_attr_e('Odnoklassniki Button','gridbone'); ?>"><i class="fab fa-odnoklassniki" aria-hidden="true" title="<?php esc_attr_e('Odnoklassniki','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('houzzlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('houzzlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-houzz" aria-label="<?php esc_attr_e('Houzz Button','gridbone'); ?>"><i class="fab fa-houzz" aria-hidden="true" title="<?php esc_attr_e('Houzz','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('pocketlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('pocketlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-pocket" aria-label="<?php esc_attr_e('Pocket Button','gridbone'); ?>"><i class="fab fa-get-pocket" aria-hidden="true" title="<?php esc_attr_e('Pocket','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('xinglink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('xinglink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-xing" aria-label="<?php esc_attr_e('XING Button','gridbone'); ?>"><i class="fab fa-xing" aria-hidden="true" title="<?php esc_attr_e('XING','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('mastodonlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('mastodonlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-mastodon" aria-label="<?php esc_attr_e('Mastodon Button','gridbone'); ?>"><i class="fab fa-mastodon" aria-hidden="true" title="<?php esc_attr_e('Mastodon','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('googleplaylink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('googleplaylink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-googleplay" aria-label="<?php esc_attr_e('Google Play Button','gridbone'); ?>"><i class="fab fa-google-play" aria-hidden="true" title="<?php esc_attr_e('Google Play','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('slidesharelink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('slidesharelink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-slideshare" aria-label="<?php esc_attr_e('SlideShare Button','gridbone'); ?>"><i class="fab fa-slideshare" aria-hidden="true" title="<?php esc_attr_e('SlideShare','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('dropboxlink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('dropboxlink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-dropbox" aria-label="<?php esc_attr_e('Dropbox Button','gridbone'); ?>"><i class="fab fa-dropbox" aria-hidden="true" title="<?php esc_attr_e('Dropbox','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('paypallink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('paypallink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-paypal" aria-label="<?php esc_attr_e('PayPal Button','gridbone'); ?>"><i class="fab fa-paypal" aria-hidden="true" title="<?php esc_attr_e('PayPal','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('viadeolink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('viadeolink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-viadeo" aria-label="<?php esc_attr_e('Viadeo Button','gridbone'); ?>"><i class="fab fa-viadeo" aria-hidden="true" title="<?php esc_attr_e('Viadeo','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('wikipedialink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('wikipedialink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-wikipedia" aria-label="<?php esc_attr_e('Wikipedia Button','gridbone'); ?>"><i class="fab fa-wikipedia-w" aria-hidden="true" title="<?php esc_attr_e('Wikipedia','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('skypeusername') ) : ?>
            <a href="skype:<?php echo esc_html( gridbone_get_option('skypeusername') ); ?>?chat" class="gridbone-header-social-icon-skype" aria-label="<?php esc_attr_e('Skype Button','gridbone'); ?>"><i class="fab fa-skype" aria-hidden="true" title="<?php esc_attr_e('Skype','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('emailaddress') ) : ?>
            <a href="mailto:<?php echo esc_html( gridbone_get_option('emailaddress') ); ?>" class="gridbone-header-social-icon-email" aria-label="<?php esc_attr_e('Email Us Button','gridbone'); ?>"><i class="far fa-envelope" aria-hidden="true" title="<?php esc_attr_e('Email Us','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('rsslink') ) : ?>
            <a href="<?php echo esc_url( gridbone_get_option('rsslink') ); ?>" target="_blank" rel="nofollow" class="gridbone-header-social-icon-rss" aria-label="<?php esc_attr_e('RSS Button','gridbone'); ?>"><i class="fas fa-rss" aria-hidden="true" title="<?php esc_attr_e('RSS','gridbone'); ?>"></i></a><?php endif; ?>
    <?php if ( gridbone_get_option('show_login_button') ) { ?><?php if (is_user_logged_in()) : ?><a href="<?php echo esc_url( wp_logout_url( get_permalink() ) ); ?>" aria-label="<?php esc_attr_e( 'Logout Button', 'gridbone' ); ?>" class="gridbone-header-social-icon-login"><i class="fas fa-sign-out-alt" aria-hidden="true" title="<?php esc_attr_e('Logout','gridbone'); ?>"></i></a><?php else : ?><a href="<?php echo esc_url( wp_login_url( get_permalink() ) ); ?>" aria-label="<?php esc_attr_e( 'Login / Register Button', 'gridbone' ); ?>" class="gridbone-header-social-icon-login"><i class="fas fa-sign-in-alt" aria-hidden="true" title="<?php esc_attr_e('Login / Register','gridbone'); ?>"></i></a><?php endif;?><?php } ?>
    <?php if ( gridbone_get_option('show_search_button') ) { ?><a href="<?php echo esc_url( '#' ); ?>" class="gridbone-header-social-icon-search" aria-label="<?php esc_attr_e('Search Button','gridbone'); ?>"><i class="fas fa-search" aria-hidden="true" title="<?php esc_attr_e('Search','gridbone'); ?>"></i></a><?php } ?>
</div>

<?php }


/**
* Author bio box
*/

function gridbone_add_author_bio_box() {
    $content='';
    if (is_single()) {
        $content .= '
            <div class="gridbone-author-bio">
            <div class="gridbone-author-bio-inside">
            <div class="gridbone-author-bio-top">
            <span class="gridbone-author-bio-gravatar">
                '. get_avatar( get_the_author_meta('email') , 80 ) .'
            </span>
            <div class="gridbone-author-bio-text">
                <div class="gridbone-author-bio-name">'.esc_html__( 'Author: ', 'gridbone' ).'<span>'. get_the_author_link() .'</span></div><div class="gridbone-author-bio-text-description">'. wp_kses_post( get_the_author_meta('description',get_query_var('author') ) ) .'</div>
            </div>
            </div>
            </div>
            </div>
        ';
    }
    return apply_filters( 'gridbone_add_author_bio_box', $content );
}


/**
* Post meta functions
*/

function gridbone_post_published_date_text() {
    if ( gridbone_is_option_set('post_published_date_text') ) {
        $post_published_date_text = gridbone_get_option('post_published_date_text');
    } else {
        $post_published_date_text = esc_html__( 'Posted on', 'gridbone' );
    }
    return apply_filters( 'gridbone_post_published_date_text', $post_published_date_text );
}

function gridbone_post_updated_date_text() {
    if ( gridbone_is_option_set('post_updated_date_text') ) {
        $post_updated_date_text = gridbone_get_option('post_updated_date_text');
    } else {
        $post_updated_date_text = esc_html__( 'Last updated on', 'gridbone' );
    }
    return apply_filters( 'gridbone_post_updated_date_text', $post_updated_date_text );
}

function gridbone_post_author_text() {
    if ( gridbone_is_option_set('post_author_text') ) {
        $post_author_text = gridbone_get_option('post_author_text');
    } else {
        $post_author_text = esc_html__( 'Posted by', 'gridbone' );
    }
    return apply_filters( 'gridbone_post_author_text', $post_author_text );
}

function gridbone_post_comments_text() {
    if ( gridbone_is_option_set('post_comments_text') ) {
        $post_comments_text = gridbone_get_option('post_comments_text');
    } else {
        $post_comments_text = '';
    }
    return apply_filters( 'gridbone_post_comments_text', $post_comments_text );
}

function gridbone_post_cat_links_text() {
    if ( gridbone_is_option_set('post_cat_links_text') ) {
        $post_cat_links_text = gridbone_get_option('post_cat_links_text');
    } else {
        $post_cat_links_text = esc_html__( 'Posted in', 'gridbone' );
    }
    return apply_filters( 'gridbone_post_cat_links_text', $post_cat_links_text );
}

function gridbone_post_tag_links_text() {
    if ( gridbone_is_option_set('post_tag_links_text') ) {
        $post_tag_links_text = gridbone_get_option('post_tag_links_text');
    } else {
        $post_tag_links_text = esc_html__( 'Tagged', 'gridbone' );
    }
    return apply_filters( 'gridbone_post_tag_links_text', $post_tag_links_text );
}

function gridbone_page_published_date_text() {
    if ( gridbone_is_option_set('page_published_date_text') ) {
        $page_published_date_text = gridbone_get_option('page_published_date_text');
    } else {
        $page_published_date_text = esc_html__( 'Posted on', 'gridbone' );
    }
    return apply_filters( 'gridbone_page_published_date_text', $page_published_date_text );
}

function gridbone_page_updated_date_text() {
    if ( gridbone_is_option_set('page_updated_date_text') ) {
        $page_updated_date_text = gridbone_get_option('page_updated_date_text');
    } else {
        $page_updated_date_text = esc_html__( 'Last updated on', 'gridbone' );
    }
    return apply_filters( 'gridbone_page_updated_date_text', $page_updated_date_text );
}

function gridbone_page_author_text() {
    if ( gridbone_is_option_set('page_author_text') ) {
        $page_author_text = gridbone_get_option('page_author_text');
    } else {
        $page_author_text = esc_html__( 'Posted by', 'gridbone' );
    }
    return apply_filters( 'gridbone_page_author_text', $page_author_text );
}

function gridbone_page_comments_text() {
    if ( gridbone_is_option_set('page_comments_text') ) {
        $page_comments_text = gridbone_get_option('page_comments_text');
    } else {
        $page_comments_text = '';
    }
    return apply_filters( 'gridbone_page_comments_text', $page_comments_text );
}


function gridbone_slide_published_date_text() {
    if ( gridbone_is_option_set('slide_published_date_text') ) {
        $slide_published_date_text = gridbone_get_option('slide_published_date_text');
    } else {
        $slide_published_date_text = esc_html__( 'Posted on', 'gridbone' );
    }
    return apply_filters( 'gridbone_slide_published_date_text', $slide_published_date_text );
}

function gridbone_slide_updated_date_text() {
    if ( gridbone_is_option_set('slide_updated_date_text') ) {
        $slide_updated_date_text = gridbone_get_option('slide_updated_date_text');
    } else {
        $slide_updated_date_text = esc_html__( 'Updated on', 'gridbone' );
    }
    return apply_filters( 'gridbone_slide_updated_date_text', $slide_updated_date_text );
}

function gridbone_slide_author_text() {
    if ( gridbone_is_option_set('slide_author_text') ) {
        $slide_author_text = gridbone_get_option('slide_author_text');
    } else {
        $slide_author_text = esc_html__( 'By', 'gridbone' );
    }
    return apply_filters( 'gridbone_slide_author_text', $slide_author_text );
}

function gridbone_slide_comments_text() {
    if ( gridbone_is_option_set('slide_comments_text') ) {
        $slide_comments_text = gridbone_get_option('slide_comments_text');
    } else {
        $slide_comments_text = '';
    }
    return apply_filters( 'gridbone_slide_comments_text', $slide_comments_text );
}

function gridbone_slide_tag_links_text() {
    if ( gridbone_is_option_set('slide_tag_links_text') ) {
        $slide_tag_links_text = gridbone_get_option('slide_tag_links_text');
    } else {
        $slide_tag_links_text = esc_html__( 'Tagged', 'gridbone' );
    }
    return apply_filters( 'gridbone_slide_tag_links_text', $slide_tag_links_text );
}

function gridbone_slider_dateformat() {
    if ( gridbone_is_option_set('slider_dateformat') ) {
        $slider_dateformat = gridbone_get_option('slider_dateformat');
    } else {
        $slider_dateformat = 'F j, Y';
    }
    return apply_filters( 'gridbone_slider_dateformat', $slider_dateformat );
}

if ( ! function_exists( 'gridbone_post_tags' ) ) :
/**
 * Prints HTML with meta information for the tags.
 */
function gridbone_post_tags() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space after the comma */
        $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'gridbone' ) );
        if ( $tags_list ) {
            /* translators: 1: list of tags. */
            printf( '<span class="gridbone-tags-links"><i class="fas fa-tags" aria-hidden="true"></i> ' . esc_html__( 'Tagged: %1$s', 'gridbone' ) . '</span>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;

if ( ! function_exists( 'gridbone_single_cats' ) ) :
function gridbone_single_cats() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space */
        $categories_list = get_the_category_list( esc_html__( ', ', 'gridbone' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */
            printf( '<span class="gridbone-entry-meta-single-cats"><i class="far fa-folder-open" aria-hidden="true"></i>&nbsp;' . __( '<span class="gridbone-sr-only">Posted in </span>%1$s', 'gridbone' ) . '</span>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;

if ( ! function_exists( 'gridbone_entry_header' ) ) :
function gridbone_entry_header() { ?>
    <?php global $post; ?>
    <?php if ( !(gridbone_get_option('hide_post_date')) || !(gridbone_get_option('hide_post_author')) ) { ?>
    <div class="gridbone-entry-meta-single">
    <?php if ( gridbone_get_option('post_date_type') == 'published' ) { ?>
        <?php if ( !(gridbone_get_option('hide_post_date')) ) { ?><span class="gridbone-entry-meta-single-date gridbone-entry-meta-single-block"><span class="gridbone-entry-meta-icon"><i class="fas fa-clock" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_post_published_date_text()) { ?><span class="gridbone-entry-meta-text"><?php echo wp_kses_post(gridbone_post_published_date_text()); ?>&nbsp;</span><?php } ?><?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php } else { ?>
        <?php if ( !(gridbone_get_option('hide_post_date')) ) { ?><span class="gridbone-entry-meta-single-date gridbone-entry-meta-single-block"><span class="gridbone-entry-meta-icon"><i class="fas fa-clock" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_post_updated_date_text()) { ?><span class="gridbone-entry-meta-text"><?php echo wp_kses_post(gridbone_post_updated_date_text()); ?>&nbsp;</span><?php } ?><?php echo esc_html( get_the_modified_date() ); ?></span><?php } ?>
    <?php } ?>
    <?php if ( !(gridbone_get_option('hide_post_author')) ) { ?><span class="gridbone-entry-meta-single-author gridbone-entry-meta-single-block"><span class="gridbone-entry-meta-icon"><i class="fas fa-user" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_post_author_text()) { ?><span class="gridbone-entry-meta-text"><?php echo wp_kses_post(gridbone_post_author_text()); ?>&nbsp;</span><?php } ?><span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;

if ( ! function_exists( 'gridbone_entry_footer' ) ) :
 /**
  * Prints HTML with meta information for the categories, tags and comments.
  */
function gridbone_entry_footer() {
    global $post; ?>
    <?php if ( (!(gridbone_get_option('hide_post_categories')) && has_category()) || (!(gridbone_get_option('hide_post_tags')) && has_tag()) || (!(gridbone_get_option('hide_comments_link')) && (! post_password_required() && ( comments_open() || get_comments_number() ))) || !(gridbone_get_option('hide_post_edit')) ) { ?>
    <footer class="entry-footer gridbone-entry-footer">
    <div class="gridbone-entry-footer-inside">
    <?php
    if ( !(gridbone_get_option('hide_post_categories')) && has_category() ) {
        if ( 'post' == get_post_type() ) {
            /* translators: used between list items, there is a space after the comma */
            $categories_list = get_the_category_list( esc_html__( ', ', 'gridbone' ) );
            if ( $categories_list ) { ?>
                <span class="gridbone-entry-cat-links gridbone-entry-meta"><span class="gridbone-entry-meta-icon"><i class="fas fa-folder-open" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_post_cat_links_text()) { ?><span class="gridbone-entry-meta-text"><?php echo wp_kses_post(gridbone_post_cat_links_text()); ?>&nbsp;</span><?php } ?><?php echo wp_kses_post( $categories_list ); ?></span>
            <?php }
        }
    }

    if ( !(gridbone_get_option('hide_post_tags')) && has_tag() ) {
        if ( 'post' == get_post_type() ) {
            /* translators: used between list items, there is a space after the comma */
            $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'gridbone' ) );
            if ( $tags_list ) { ?>
                <span class="gridbone-entry-tags-links gridbone-entry-meta"><span class="gridbone-entry-meta-icon"><i class="fas fa-tags" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_post_tag_links_text()) { ?><span class="gridbone-entry-meta-text"><?php echo wp_kses_post(gridbone_post_tag_links_text()); ?>&nbsp;</span><?php } ?><?php echo wp_kses_post( $tags_list ); ?></span>
            <?php }
        }
    }

    if ( !(gridbone_get_option('hide_comments_link')) ) {
        if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
            <span class="gridbone-entry-comment gridbone-entry-meta"><span class="gridbone-entry-meta-icon"><i class="fas fa-comments" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_post_comments_text()) { ?><span class="gridbone-entry-meta-text"><?php echo wp_kses_post(gridbone_post_comments_text()); ?>&nbsp;</span><?php } ?><?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( '0 Comments<span class="gridbone-sr-only"> on %s</span>', 'gridbone' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
        <?php
        }
    }

    if ( !(gridbone_get_option('hide_post_edit')) ) {
        edit_post_link( sprintf( wp_kses( /* translators: %s: Name of current post. Only visible to screen readers */ __( 'Edit<span class="gridbone-sr-only"> %s</span>', 'gridbone' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ), '<span class="gridbone-entry-edit-link gridbone-entry-meta"><span class="gridbone-entry-meta-icon"><i class="fas fa-pencil-alt" aria-hidden="true"></i>&nbsp;</span>', '</span>' );
    }
    ?>
    </div>
    </footer>
    <?php } ?>
    <?php
}
endif;

if ( ! function_exists( 'gridbone_page_postmeta' ) ) :
function gridbone_page_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridbone_get_option('hide_page_author')) || !(gridbone_get_option('hide_page_date')) || !(gridbone_get_option('hide_page_comments')) ) { ?>
    <?php if ( !((is_front_page()) && (gridbone_get_option('hide_static_page_meta'))) ) { ?>
    <div class="gridbone-entry-meta-single">
    <?php if ( gridbone_get_option('page_date_type') == 'published' ) { ?>
        <?php if ( !(gridbone_get_option('hide_page_date')) ) { ?><span class="gridbone-entry-meta-single-date"><span class="gridbone-entry-meta-icon"><i class="fas fa-clock" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_page_published_date_text()) { ?><span class="gridbone-entry-meta-text"><?php echo wp_kses_post(gridbone_page_published_date_text()); ?>&nbsp;</span><?php } ?><?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php } else { ?>
        <?php if ( !(gridbone_get_option('hide_page_date')) ) { ?><span class="gridbone-entry-meta-single-date"><span class="gridbone-entry-meta-icon"><i class="fas fa-clock" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_page_updated_date_text()) { ?><span class="gridbone-entry-meta-text"><?php echo wp_kses_post(gridbone_page_updated_date_text()); ?>&nbsp;</span><?php } ?><?php echo esc_html( get_the_modified_date() ); ?></span><?php } ?>
    <?php } ?>
    <?php if ( !(gridbone_get_option('hide_page_author')) ) { ?><span class="gridbone-entry-meta-single-author"><span class="gridbone-entry-meta-icon"><i class="fas fa-user" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_page_author_text()) { ?><span class="gridbone-entry-meta-text"><?php echo wp_kses_post(gridbone_page_author_text()); ?>&nbsp;</span><?php } ?><span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(gridbone_get_option('hide_page_comments')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridbone-entry-meta-single-comments"><span class="gridbone-entry-meta-icon"><i class="fas fa-comments" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_page_comments_text()) { ?><span class="gridbone-entry-meta-text"><?php echo wp_kses_post(gridbone_page_comments_text()); ?>&nbsp;</span><?php } ?><?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="gridbone-sr-only"> on %s</span>', 'gridbone' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    </div>
    <?php } ?>
    <?php } ?>
<?php }
endif;

if ( ! function_exists( 'gridbone_slider_cats' ) ) :
function gridbone_slider_cats() {
    global $post;
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space */
        $categories_list = get_the_category_list( esc_html__( '&nbsp;', 'gridbone' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */
            printf( '<div class="gridbone-slider-post-categories gridbone-slider-post-details-block">' . __( '<span class="gridbone-sr-only">Posted in </span>%1$s', 'gridbone' ) . '</div>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;

if ( ! function_exists( 'gridbone_slider_postmeta' ) ) :
function gridbone_slider_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridbone_get_option('hide_slide_date')) || !(gridbone_get_option('hide_slide_author')) || (gridbone_get_option('show_slide_comments') && (! post_password_required() && ( comments_open() || get_comments_number() ))) || (gridbone_get_option('show_slide_tags') && has_tag() && ('post' == get_post_type())) ) { ?>
    <div class="gridbone-slider-meta">
    <?php if ( gridbone_get_option('post_date_type') == 'published' ) { ?>
        <?php if ( !(gridbone_get_option('hide_slide_date')) ) { ?><span class="gridbone-slider-meta-date gridbone-slider-meta-block"><span class="gridbone-slider-meta-icon"><i class="fas fa-clock" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_slide_published_date_text()) { ?><span class="gridbone-slider-meta-text"><?php echo wp_kses_post(gridbone_slide_published_date_text()); ?>&nbsp;</span><?php } ?><?php echo esc_html( get_the_date(gridbone_slider_dateformat()) ); ?></span><?php } ?>
    <?php } else { ?>
        <?php if ( !(gridbone_get_option('hide_slide_date')) ) { ?><span class="gridbone-slider-meta-date gridbone-slider-meta-block"><span class="gridbone-slider-meta-icon"><i class="fas fa-clock" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_slide_updated_date_text()) { ?><span class="gridbone-slider-meta-text"><?php echo wp_kses_post(gridbone_slide_updated_date_text()); ?>&nbsp;</span><?php } ?><?php echo esc_html( get_the_modified_date(gridbone_slider_dateformat()) ); ?></span><?php } ?>
    <?php } ?>
    <?php if ( !(gridbone_get_option('hide_slide_author')) ) { ?><span class="gridbone-slider-meta-author gridbone-slider-meta-block"><span class="gridbone-slider-meta-icon"><i class="fas fa-user" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_slide_author_text()) { ?><span class="gridbone-slider-meta-text"><?php echo wp_kses_post(gridbone_slide_author_text()); ?>&nbsp;</span><?php } ?><span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( gridbone_get_option('show_slide_comments') && (! post_password_required() && ( comments_open() || get_comments_number() )) ) { ?><span class="gridbone-slider-meta-comments gridbone-slider-meta-block"><span class="gridbone-slider-meta-icon"><i class="fas fa-comments" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_slide_comments_text()) { ?><span class="gridbone-slider-meta-text"><?php echo wp_kses_post(gridbone_slide_comments_text()); ?>&nbsp;</span><?php } ?><?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( '0 Comments<span class="gridbone-sr-only"> on %s</span>', 'gridbone' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span><?php } ?>
    <?php if ( gridbone_get_option('show_slide_tags') && has_tag() && ('post' == get_post_type()) ) { ?><?php /* translators: used between list items, there is a space after the comma */ $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'gridbone' ) ); ?><?php if ( $tags_list ) { ?><span class="gridbone-slider-meta-tags gridbone-slider-meta-block"><span class="gridbone-slider-meta-icon"><i class="fas fa-tags" aria-hidden="true"></i>&nbsp;</span><?php if(gridbone_slide_tag_links_text()) { ?><span class="gridbone-slider-meta-text"><?php echo wp_kses_post(gridbone_slide_tag_links_text()); ?>&nbsp;</span><?php } ?><?php echo wp_kses_post( $tags_list ); ?></span><?php } ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;


/**
* Posts navigation functions
*/

if ( ! function_exists( 'gridbone_wp_pagenavi' ) ) :
function gridbone_wp_pagenavi() {
    ?>
    <nav class="navigation posts-navigation gridbone-clearfix" role="navigation">
        <?php wp_pagenavi(); ?>
    </nav><!-- .navigation -->
    <?php
}
endif;

if ( ! function_exists( 'gridbone_posts_navigation' ) ) :
function gridbone_posts_navigation() {
    if ( !(gridbone_get_option('hide_posts_navigation')) ) {
        if ( function_exists( 'wp_pagenavi' ) ) {
            gridbone_wp_pagenavi();
        } else {
            if ( gridbone_get_option('posts_navigation_type') === 'normalnavi' ) {
                the_posts_navigation(array('prev_text' => esc_html__( 'Older posts', 'gridbone' ), 'next_text' => esc_html__( 'Newer posts', 'gridbone' )));
            } else {
                the_posts_pagination(array('mid_size' => 2, 'prev_text' => esc_html__( '&larr; Newer posts', 'gridbone' ), 'next_text' => esc_html__( 'Older posts &rarr;', 'gridbone' )));
            }
        }
    }
}
endif;

if ( ! function_exists( 'gridbone_post_navigation' ) ) :
function gridbone_post_navigation() {
    global $post;
    if ( !(gridbone_get_option('hide_post_navigation')) ) {
            the_post_navigation(array('prev_text' => esc_html__( '%title &rarr;', 'gridbone' ), 'next_text' => esc_html__( '&larr; %title', 'gridbone' )));
    }
}
endif;


/**
* WooCommerce support
*/

// Checking if WooCommerce is active
if ( GRIDBONE_WOOCOMMERCE_ACTIVE ) {

remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);
add_action('woocommerce_before_main_content', 'gridbone_woo_wrapper_start', 10);
add_action('woocommerce_after_main_content', 'gridbone_woo_wrapper_end', 10);

function gridbone_woo_wrapper_start() { ?>

    <div class="gridbone-main-wrapper gridbone-clearfix" id="gridbone-main-wrapper" itemscope="itemscope" itemtype="http://schema.org/Blog" role="main">
    <div class="theiaStickySidebar">
    <div class="gridbone-main-wrapper-inside gridbone-clearfix">

    <?php gridbone_before_main_content(); ?>

    <div class="gridbone-posts-wrapper" id="gridbone-posts-wrapper">

    <div class="gridbone-posts gridbone-box">
    <div class="gridbone-box-inside gridbone-woocommerce-box-inside">
    <div class="gridbone-posts-content">

<?php }

function gridbone_woo_wrapper_end() { ?>

    </div>
    </div>
    </div>

    </div><!--/#gridbone-posts-wrapper -->

    <?php gridbone_after_main_content(); ?>

    </div>
    </div>
    </div><!-- /#gridbone-main-wrapper -->

    <?php //get_sidebar(); ?>

<?php }

}


/**
* Menu Functions
*/

// Get our wp_nav_menu() fallback, wp_page_menu(), to show a "Home" link as the first item
function gridbone_page_menu_args( $args ) {
    $args['show_home'] = true;
    return $args;
}
add_filter( 'wp_page_menu_args', 'gridbone_page_menu_args' );

function gridbone_primary_menu_text() {
   $menu_text = esc_html__( 'Menu', 'gridbone' );
    if ( gridbone_get_option('primary_menu_text') ) {
        $menu_text = gridbone_get_option('primary_menu_text');
    }
   return apply_filters( 'gridbone_primary_menu_text', $menu_text );
}

function gridbone_secondary_menu_text() {
   $menu_text = esc_html__( 'Menu', 'gridbone' );
    if ( gridbone_get_option('secondary_menu_text') ) {
        $menu_text = gridbone_get_option('secondary_menu_text');
    }
   return apply_filters( 'gridbone_secondary_menu_text', $menu_text );
}

function gridbone_secondary_menu_location() {
    $secondary_menu_location = 'before-header';
    if ( gridbone_get_option('secondary_menu_location') ) {
        $secondary_menu_location = gridbone_get_option('secondary_menu_location');
    }
    return apply_filters( 'gridbone_secondary_menu_location', $secondary_menu_location );
}

function gridbone_primary_fallback_menu() {
   wp_page_menu( array(
        'sort_column'  => 'menu_order, post_title',
        'menu_id'      => 'gridbone-menu-primary-navigation',
        'menu_class'   => 'gridbone-primary-nav-menu gridbone-menu-primary',
        'container'    => 'ul',
        'echo'         => true,
        'link_before'  => '',
        'link_after'   => '',
        'before'       => '',
        'after'        => '',
        'item_spacing' => 'discard',
        'walker'       => '',
    ) );
}

function gridbone_secondary_fallback_menu() {
   wp_page_menu( array(
        'sort_column'  => 'menu_order, post_title',
        'menu_id'      => 'gridbone-menu-secondary-navigation',
        'menu_class'   => 'gridbone-secondary-nav-menu gridbone-menu-secondary',
        'container'    => 'ul',
        'echo'         => true,
        'link_before'  => '',
        'link_after'   => '',
        'before'       => '',
        'after'        => '',
        'item_spacing' => 'discard',
        'walker'       => '',
    ) );
}

function gridbone_primary_menu_area() {
if ( gridbone_is_primary_menu_active() ) { ?>
<div class="gridbone-container gridbone-primary-menu-container gridbone-clearfix">
<div class="gridbone-primary-menu-container-inside gridbone-clearfix">
<nav class="gridbone-nav-primary" id="gridbone-primary-navigation" itemscope="itemscope" itemtype="http://schema.org/SiteNavigationElement" aria-label="<?php esc_attr_e( 'Primary Menu', 'gridbone' ); ?>">
<div class="gridbone-outer-wrapper">
<button class="gridbone-primary-responsive-menu-icon" aria-controls="gridbone-menu-primary-navigation" aria-expanded="false"><?php esc_html_e( 'Menu', 'gridbone' ); ?></button>
<?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'gridbone-menu-primary-navigation', 'menu_class' => 'gridbone-primary-nav-menu gridbone-menu-primary gridbone-clearfix', 'fallback_cb' => 'gridbone_primary_fallback_menu', 'container' => '', ) ); ?>
</div>
</nav>
</div>
</div>
<?php }
}

function gridbone_secondary_menu_area() {
if ( gridbone_is_secondary_menu_active() ) { ?>
<div class="gridbone-container gridbone-secondary-menu-container gridbone-clearfix">
<div class="gridbone-secondary-menu-container-inside gridbone-clearfix">
<nav class="gridbone-nav-secondary" id="gridbone-secondary-navigation" itemscope="itemscope" itemtype="http://schema.org/SiteNavigationElement" aria-label="<?php esc_attr_e( 'Secondary Menu', 'gridbone' ); ?>">
<div class="gridbone-outer-wrapper">
<button class="gridbone-secondary-responsive-menu-icon" aria-controls="gridbone-menu-secondary-navigation" aria-expanded="false"><?php echo esc_html( gridbone_secondary_menu_text() ); ?></button>
<?php wp_nav_menu( array( 'theme_location' => 'secondary', 'menu_id' => 'gridbone-menu-secondary-navigation', 'menu_class' => 'gridbone-secondary-nav-menu gridbone-menu-secondary gridbone-clearfix', 'fallback_cb' => 'gridbone_secondary_fallback_menu', 'container' => '', ) ); ?>
</div>
</nav>
</div>
</div>
<?php }
}


/**
* Header Notice
*/

function gridbone_is_header_notice_active() {
    $header_notice_active = false;

    if ( gridbone_get_option('enable_header_notice') ) {
        $header_notice_active = true;
    }

    return apply_filters( 'gridbone_is_header_notice_active', $header_notice_active );
}

function gridbone_header_notice_text() {
    $header_notice_text = '';

    if ( gridbone_get_option('header_notice_text') ) {
        $header_notice_text = gridbone_get_option('header_notice_text');
    }

    return apply_filters( 'gridbone_header_notice_text', $header_notice_text );
}

if ( ! function_exists( 'gridbone_header_notice' ) ) :

function gridbone_header_notice() { ?>
<?php if ( gridbone_is_header_notice_active() && gridbone_header_notice_text() ) { ?>
<div class="gridbone-header-notice gridbone-clearfix">
<div class="gridbone-outer-wrapper">
    <?php echo wp_kses_post( force_balance_tags( do_shortcode(gridbone_header_notice_text()) ) ); ?>
</div>
</div>
<?php } ?>
<?php }

endif;

function gridbone_header_notice_area() {
    if ( gridbone_is_header_notice_active() && gridbone_header_notice_text() ) {
        if ( 'front-page' === gridbone_get_option('header_notice_display') ) {
            if ( is_front_page() && is_home() && !is_paged() ) {
                gridbone_header_notice();
            }
        } elseif ( 'front-page-static' === gridbone_get_option('header_notice_display') ) {
            if ( is_front_page() && is_singular() ) {
                gridbone_header_notice();
            }
        } elseif ( 'blog-posts-index' === gridbone_get_option('header_notice_display') ) {
            if ( is_home() && !is_paged() ) {
                gridbone_header_notice();
            }
        } elseif ( 'everywhere' === gridbone_get_option('header_notice_display') ) {
            gridbone_header_notice();
        } else {
            gridbone_header_notice();
        }
    }
}


/**
* Slider
*/

function gridbone_slider_thumb_style() {
   $thumb_style = 'gridbone-480w-480h-image';
    if ( gridbone_get_option('slider_thumb_style') ) {
        $thumb_style = gridbone_get_option('slider_thumb_style');
    }
   return apply_filters( 'gridbone_slider_thumb_style', $thumb_style );
}

function gridbone_slider_thumb_class() {
    if ( 'gridbone-125w-125h-image' === gridbone_slider_thumb_style() ) {
        $thumb_class = 'gridbone-125w-125h-slider-thumbnail gridbone-square-thumbnail';
    } elseif ( 'gridbone-480w-360h-image' === gridbone_slider_thumb_style() ) {
        $thumb_class = 'gridbone-480w-360h-slider-thumbnail gridbone-small-height-thumbnail';
    } elseif ( 'gridbone-480w-480h-image' === gridbone_slider_thumb_style() ) {
        $thumb_class = 'gridbone-480w-480h-slider-thumbnail gridbone-square-thumbnail';
    } else {
        $thumb_class = 'gridbone-480w-480h-slider-thumbnail gridbone-square-thumbnail';
    }
    return apply_filters( 'gridbone_slider_thumb_class', $thumb_class );
}

function gridbone_slider_no_thumb_url() {
    if ( 'gridbone-125w-125h-image' === gridbone_slider_thumb_style() ) {
        $no_thumb_url = get_template_directory_uri() . '/assets/images/no-image-125-125.png';
    } elseif ( 'gridbone-480w-360h-image' === gridbone_slider_thumb_style() ) {
        $no_thumb_url = get_template_directory_uri() . '/assets/images/no-image-480-360.png';
    } elseif ( 'gridbone-480w-480h-image' === gridbone_slider_thumb_style() ) {
        $no_thumb_url = get_template_directory_uri() . '/assets/images/no-image-480-480.png';
    } else {
        $no_thumb_url = get_template_directory_uri() . '/assets/images/no-image-480-480.png';
    }
    return apply_filters( 'gridbone_slider_no_thumb_url', $no_thumb_url );
}

function gridbone_is_slider_active() {
    $slider_active = false;

    if ( gridbone_get_option('enable_slider') ) {
        $slider_active = true;
    }

    return apply_filters( 'gridbone_is_slider_active', $slider_active );
}

if ( ! function_exists( 'gridbone_slider' ) ) :

function gridbone_slider() { ?>

<?php gridbone_before_slider(); ?>

<div class="gridbone-slider-wrapper-outside gridbone-clearfix">
<div class="gridbone-slider-wrapper">
<div class="gridbone-outer-wrapper">
    <?php
    $slider_length = 10;
    if ( gridbone_get_option('slider_length') ) {
        $slider_length = gridbone_get_option('slider_length');
    }

    $slider_post_type = 'recentposts';
    if ( gridbone_get_option('slider_post_type') ) {
        $slider_post_type = gridbone_get_option('slider_post_type');
    }

    $slider_cat = gridbone_get_option('slider_cat');
    $slider_tag = gridbone_get_option('slider_tag');

    $slider_post_orderby = 'date';
    if ( gridbone_get_option('slider_post_orderby') ) {
        $slider_post_orderby = gridbone_get_option('slider_post_orderby');
    }

    $slider_post_order = 'DESC';
    if ( gridbone_get_option('slider_post_order') ) {
        $slider_post_order = gridbone_get_option('slider_post_order');
    }

    $slider_dateformat = 'F j, Y';
    if ( gridbone_get_option('slider_dateformat') ) {
        $slider_dateformat = gridbone_get_option('slider_dateformat');
    }

    $post_title_length_slider = 6;
    if ( gridbone_get_option('post_title_length_slider') ) {
        $post_title_length_slider = gridbone_get_option('post_title_length_slider');
    }

    $snippet_length_slider = 17;
    if ( gridbone_get_option('snippet_length_slider') ) {
        $snippet_length_slider = gridbone_get_option('snippet_length_slider');
    }

    $snippet_type_slider = 'postexcerpt';
    if ( gridbone_get_option('snippet_type_slider') ) {
        $snippet_type_slider = gridbone_get_option('snippet_type_slider');
    }

    if(($slider_post_type === 'catposts') && $slider_cat) {
        $slider_query = new WP_Query( array( 'orderby' => $slider_post_orderby, 'order' => $slider_post_order, 'posts_per_page' => $slider_length, 'nopaging' => false, 'post_status' => array( 'publish' ), 'ignore_sticky_posts' => true, 'post_type' => array( 'post' ), 'cat' => $slider_cat, 'no_found_rows' => true ) );
    } elseif(($slider_post_type === 'tagposts') && $slider_tag) {
        $slider_query = new WP_Query( array( 'orderby' => $slider_post_orderby, 'order' => $slider_post_order, 'posts_per_page' => $slider_length, 'nopaging' => false, 'post_status' => array( 'publish' ), 'ignore_sticky_posts' => true, 'post_type' => array( 'post' ), 'tag_id' => $slider_tag, 'no_found_rows' => true ) );
    } else {
        $slider_query = new WP_Query( array( 'orderby' => $slider_post_orderby, 'order' => $slider_post_order, 'posts_per_page' => $slider_length, 'nopaging' => false, 'post_status' => array( 'publish' ), 'ignore_sticky_posts' => true, 'post_type' => array( 'post' ), 'no_found_rows' => true ) );
    }

    if ($slider_query->have_posts()) : ?>

    <?php if ( gridbone_get_option('show_slider_heading') ) { ?>
    <?php if ( gridbone_get_option('slider_heading') ) : ?>
    <div class="gridbone-slider-header"><div class="gridbone-slider-header-inside"><h2 class="gridbone-slider-heading"><span class="gridbone-slider-heading-inside"><?php echo esc_html( gridbone_get_option('slider_heading') ); ?></span></h2></div></div>
    <?php else : ?>
    <div class="gridbone-slider-header"><div class="gridbone-slider-header-inside"><h2 class="gridbone-slider-heading"><span class="gridbone-slider-heading-inside"><?php esc_html_e( 'Featured Posts Slider', 'gridbone' ); ?></span></h2></div></div>
    <?php endif; ?>
    <?php } ?>

    <div class="gridbone-slider-posts gridbone-clearfix">
    <div class="gridbone-posts-carousel">
    <div class="owl-carousel owl-theme">
    <?php while ($slider_query->have_posts()) : $slider_query->the_post();  ?>

        <div class="gridbone-slide-item">
        <?php $gridbone_slider_post_content = get_the_content(); ?>
        <div id="gridbone-slider-post-<?php the_ID(); ?>" class="gridbone-slider-post <?php echo esc_attr( gridbone_slider_thumb_class() ); ?>">
        <div class="gridbone-slider-post-inside">

        <?php if ( !(gridbone_get_option('hide_thumbnail_slider')) ) { ?>
        <?php if ( has_post_thumbnail() ) { ?>
        <div class="gridbone-slider-post-thumbnail gridbone-slider-post-block">
            <?php if ( gridbone_get_option('remove_thumbnail_slider_link') ) { ?>
                <?php the_post_thumbnail(gridbone_slider_thumb_style(), array('class' => 'gridbone-slider-post-thumbnail-img', 'title' => the_title_attribute('echo=0'))); ?>
            <?php } else { ?>
                <a href="<?php echo esc_url( get_permalink() ); ?>" class="gridbone-slider-post-thumbnail-link" title="<?php /* translators: %s: post title. */ echo esc_attr( sprintf( __( 'Permanent Link to %s', 'gridbone' ), the_title_attribute( 'echo=0' ) ) ); ?>"><?php the_post_thumbnail(gridbone_slider_thumb_style(), array('class' => 'gridbone-slider-post-thumbnail-img', 'title' => the_title_attribute('echo=0'))); ?></a>
            <?php } ?>
        </div>
        <?php } else { ?>
        <?php if ( !(gridbone_get_option('hide_default_thumbnail_slider')) ) { ?>
        <div class="gridbone-slider-post-thumbnail gridbone-slider-post-thumbnail-default gridbone-slider-post-block">
            <?php if ( gridbone_get_option('remove_thumbnail_slider_link') ) { ?>
                <img src="<?php echo esc_url( gridbone_slider_no_thumb_url() ); ?>" class="gridbone-slider-post-thumbnail-img"/>
            <?php } else { ?>
                <a href="<?php echo esc_url( get_permalink() ); ?>" class="gridbone-slider-post-thumbnail-link" title="<?php /* translators: %s: post title. */ echo esc_attr( sprintf( __( 'Permanent Link to %s', 'gridbone' ), the_title_attribute( 'echo=0' ) ) ); ?>"><img src="<?php echo esc_url( gridbone_slider_no_thumb_url() ); ?>" class="gridbone-slider-post-thumbnail-img"/></a>
            <?php } ?>
        </div>
        <?php } ?>
        <?php } ?>
        <?php } ?>

        <?php if ( !(gridbone_get_option('hide_post_title_slider')) || !(gridbone_get_option('hide_post_snippet_slider')) || (!(gridbone_get_option('hide_slide_cats')) && has_category() && ('post' == get_post_type())) || !(gridbone_get_option('hide_slide_date')) || (gridbone_get_option('show_slide_comments') && (! post_password_required() && ( comments_open() || get_comments_number() ))) || !(gridbone_get_option('hide_slide_author')) || (gridbone_get_option('show_slide_tags') && has_tag() && ('post' == get_post_type())) ) { ?>
        <div class="gridbone-slider-post-details gridbone-slider-post-block">
        <?php if ( !(gridbone_get_option('hide_slide_cats')) && has_category() && ('post' == get_post_type()) ) { ?>
            <?php gridbone_slider_cats(); ?>
        <?php } ?>

        <?php if ( !(gridbone_get_option('hide_post_title_slider')) ) { ?>
            <?php if ( gridbone_get_option('remove_post_title_slider_link') ) { ?>

                <?php if ( gridbone_get_option('limit_slider_post_titles') ) { ?>
                    <h3 class="gridbone-slider-post-title gridbone-slider-post-details-block"><?php echo esc_html( wp_trim_words( get_the_title(), $post_title_length_slider, '...' ) ); ?></h3>
                <?php } else { ?>
                    <?php the_title( '<h3 class="gridbone-slider-post-title gridbone-slider-post-details-block">', '</h3>' ); ?>
                <?php } ?>

            <?php } else { ?>

                <?php if ( gridbone_get_option('limit_slider_post_titles') ) { ?>
                    <h3 class="gridbone-slider-post-title gridbone-slider-post-details-block"><a href="<?php echo esc_url( get_permalink() ); ?>" rel="bookmark"><?php echo esc_html( wp_trim_words( get_the_title(), $post_title_length_slider, '...' ) ); ?></a></h3>
                <?php } else { ?>
                    <?php the_title( sprintf( '<h3 class="gridbone-slider-post-title gridbone-slider-post-details-block"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h3>' ); ?>
                <?php } ?>

            <?php } ?>
        <?php } ?>

        <?php if ( !(gridbone_get_option('hide_post_snippet_slider')) ) { ?>
            <?php if ( !empty( $gridbone_slider_post_content ) ) { ?>
                <?php if(($snippet_type_slider === 'postexcerpt')) { ?>
                    <div class="gridbone-slider-post-snippet gridbone-slider-post-excerpt gridbone-slider-post-details-block"><div class="gridbone-slider-post-snippet-inside"><?php the_excerpt(); ?></div></div>
                <?php } else { ?>
                    <div class="gridbone-slider-post-snippet gridbone-slider-post-details-block"><div class="gridbone-slider-post-snippet-inside"><?php echo esc_html( wp_trim_words( get_the_content(), $snippet_length_slider, '...' ) ); ?></div></div>
                <?php } ?>
            <?php } ?>
        <?php } ?>

        <?php gridbone_slider_postmeta(); ?>
        </div>
        <?php } ?>

        </div>
        </div>
        </div>

    <?php endwhile; ?>
    </div>
    </div>
    </div>

    <?php wp_reset_postdata();  // Restore global post data stomped by the_post().
    endif; ?>
</div>
</div>
</div>

<?php gridbone_after_slider(); ?>

<?php }

endif;

function gridbone_slider_area() {
    if ( gridbone_is_slider_active() ) {
        if ( 'front-page' === gridbone_get_option('slider_display') ) {
            if ( is_front_page() && is_home() && !is_paged() ) {
                gridbone_slider();
            }
        } elseif ( 'front-page-static' === gridbone_get_option('slider_display') ) {
            if ( is_front_page() && is_singular() ) {
                gridbone_slider();
            }
        } elseif ( 'blog-posts-index' === gridbone_get_option('slider_display') ) {
            if ( is_home() && !is_paged() ) {
                gridbone_slider();
            }
        } elseif ( 'everywhere' === gridbone_get_option('slider_display') ) {
                gridbone_slider();
        } else {
            if ( is_front_page() && is_home() && !is_paged() ) {
                gridbone_slider();
            }
        }
    }
}


/**
* Footer Notice
*/

function gridbone_is_footer_notice_active() {
    $footer_notice_active = false;

    if ( gridbone_get_option('enable_footer_notice') ) {
        $footer_notice_active = true;
    }

    return apply_filters( 'gridbone_is_footer_notice_active', $footer_notice_active );
}

function gridbone_footer_notice_text() {
    $footer_notice_text = '';

    if ( gridbone_get_option('footer_notice_text') ) {
        $footer_notice_text = gridbone_get_option('footer_notice_text');
    }

    return apply_filters( 'gridbone_footer_notice_text', $footer_notice_text );
}

if ( ! function_exists( 'gridbone_footer_notice' ) ) :

function gridbone_footer_notice() { ?>
<?php if ( gridbone_is_footer_notice_active() && gridbone_footer_notice_text() ) { ?>
<div class="gridbone-footer-notice gridbone-clearfix">
<div class="gridbone-outer-wrapper">
    <?php echo wp_kses_post( force_balance_tags( do_shortcode(gridbone_footer_notice_text()) ) ); ?>
</div>
</div>
<?php } ?>
<?php }

endif;

function gridbone_footer_notice_area() {
    if ( gridbone_is_footer_notice_active() && gridbone_footer_notice_text() ) {
        if ( 'front-page' === gridbone_get_option('footer_notice_display') ) {
            if ( is_front_page() && is_home() && !is_paged() ) {
                gridbone_footer_notice();
            }
        } elseif ( 'front-page-static' === gridbone_get_option('footer_notice_display') ) {
            if ( is_front_page() && is_singular() ) {
                gridbone_footer_notice();
            }
        } elseif ( 'blog-posts-index' === gridbone_get_option('footer_notice_display') ) {
            if ( is_home() && !is_paged() ) {
                gridbone_footer_notice();
            }
        } elseif ( 'everywhere' === gridbone_get_option('footer_notice_display') ) {
            gridbone_footer_notice();
        } else {
            gridbone_footer_notice();
        }
    }
}


/**
* Header Functions
*/

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function gridbone_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'gridbone_pingback_header' );

// Get custom-logo URL
function gridbone_custom_logo() {
    if ( ! has_custom_logo() ) {return;}
    $gridbone_custom_logo_id = get_theme_mod( 'custom_logo' );
    $gridbone_logo = wp_get_attachment_image_src( $gridbone_custom_logo_id , 'full' );
    $gridbone_logo_src = $gridbone_logo[0];
    return apply_filters( 'gridbone_custom_logo', $gridbone_logo_src );
}

// Site Title
function gridbone_site_title() {
    if ( is_front_page() && is_home() ) { ?>
            <h1 class="gridbone-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <?php if ( !(gridbone_get_option('hide_tagline')) ) { ?><p class="gridbone-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_home() ) { ?>
            <h1 class="gridbone-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <?php if ( !(gridbone_get_option('hide_tagline')) ) { ?><p class="gridbone-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_singular() ) { ?>
            <p class="gridbone-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridbone_get_option('hide_tagline')) ) { ?><p class="gridbone-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_category() ) { ?>
            <p class="gridbone-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridbone_get_option('hide_tagline')) ) { ?><p class="gridbone-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_tag() ) { ?>
            <p class="gridbone-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridbone_get_option('hide_tagline')) ) { ?><p class="gridbone-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_author() ) { ?>
            <p class="gridbone-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridbone_get_option('hide_tagline')) ) { ?><p class="gridbone-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_archive() && !is_category() && !is_tag() && !is_author() ) { ?>
            <p class="gridbone-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridbone_get_option('hide_tagline')) ) { ?><p class="gridbone-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_search() ) { ?>
            <p class="gridbone-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridbone_get_option('hide_tagline')) ) { ?><p class="gridbone-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_404() ) { ?>
            <p class="gridbone-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridbone_get_option('hide_tagline')) ) { ?><p class="gridbone-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } else { ?>
            <h1 class="gridbone-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <?php if ( !(gridbone_get_option('hide_tagline')) ) { ?><p class="gridbone-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php }
}

function gridbone_header_image_destination() {
    $url = home_url( '/' );

    if ( gridbone_get_option('header_image_destination') ) {
        $url = gridbone_get_option('header_image_destination');
    }

    return apply_filters( 'gridbone_header_image_destination', $url );
}

function gridbone_header_image_alt_text() {
    $header_image_alt_text = get_bloginfo( 'name' );

    if ( gridbone_get_option('header_image_alt_text') ) {
        $header_image_alt_text = gridbone_get_option('header_image_alt_text');
    }

    return apply_filters( 'gridbone_header_image_alt_text', $header_image_alt_text );
}

function gridbone_header_image_markup() {
    global $post;

    if ( get_header_image() ) {
        if ( gridbone_get_option('remove_header_image_link') ) {
            the_header_image_tag( array( 'class' => 'gridbone-header-img', 'alt' => esc_attr( gridbone_header_image_alt_text() ) ) );
        } else { ?>
            <a href="<?php echo esc_url( gridbone_header_image_destination() ); ?>" rel="home" class="gridbone-header-img-link"><?php the_header_image_tag( array( 'class' => 'gridbone-header-img', 'alt' => esc_attr( gridbone_header_image_alt_text() ) ) ); ?></a>
        <?php }
    }
}

function gridbone_header_image_details() {
    global $post;

    $header_image_custom_title = '';
    if ( gridbone_get_option('header_image_custom_title') ) {
        $header_image_custom_title = gridbone_get_option('header_image_custom_title');
    }

    $header_image_custom_description = '';
    if ( gridbone_get_option('header_image_custom_description') ) {
        $header_image_custom_description = gridbone_get_option('header_image_custom_description');
    }

    if ( !(gridbone_get_option('hide_header_image_details')) ) {
    if ( gridbone_get_option('header_image_custom_text') ) {
        if ( $header_image_custom_title || $header_image_custom_description ) { ?>
            <div class="gridbone-header-image-info">
            <div class="gridbone-header-image-info-inside">
                <?php if ( !(gridbone_get_option('hide_header_image_title')) ) { ?><?php if ( $header_image_custom_title ) { ?><p class="gridbone-header-image-site-title gridbone-header-image-block"><?php echo wp_kses_post( force_balance_tags( do_shortcode($header_image_custom_title) ) ); ?></p><?php } ?><?php } ?>
                <?php if ( !(gridbone_get_option('hide_header_image_description')) ) { ?><?php if ( $header_image_custom_description ) { ?><p class="gridbone-header-image-site-description gridbone-header-image-block"><?php echo wp_kses_post( force_balance_tags( do_shortcode($header_image_custom_description) ) ); ?></p><?php } ?><?php } ?>
            </div>
            </div>
        <?php }
    } else { ?>
        <div class="gridbone-header-image-info">
        <div class="gridbone-header-image-info-inside">
            <?php if ( !(gridbone_get_option('hide_header_image_title')) ) { ?><p class="gridbone-header-image-site-title gridbone-header-image-block"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p><?php } ?>
            <?php if ( !(gridbone_get_option('hide_header_image_description')) ) { ?><p class="gridbone-header-image-site-description gridbone-header-image-block"><?php bloginfo( 'description' ); ?></p><?php } ?>
        </div>
        </div>
    <?php }
    }
}

function gridbone_header_image_wrapper() { ?>
    <div class="gridbone-header-image gridbone-clearfix">
    <?php gridbone_header_image_markup(); ?>
    <?php gridbone_header_image_details(); ?>
    </div>
    <?php
}

function gridbone_header_image() {
    if ( gridbone_get_option('hide_header_image') ) { return; }
    if ( get_header_image() ) {
        gridbone_header_image_wrapper();
    }
}

function gridbone_logo_max_width() {
    $logo_max_width = '300px';

    if ( gridbone_get_option('logo_max_width') ) {
        $logo_max_width = gridbone_get_option('logo_max_width');
    }

    return apply_filters( 'gridbone_logo_max_width', $logo_max_width );
}


/**
* Css Classes Functions
*/

// Category ids in post class
function gridbone_category_id_class($classes) {
    global $post;
    foreach((get_the_category($post->ID)) as $category) {
        $classes[] = 'wpcat-' . $category->cat_ID . '-id';
    }
    return apply_filters( 'gridbone_category_id_class', $classes );
}
add_filter('post_class', 'gridbone_category_id_class');


// Adds custom classes to the array of body classes.
function gridbone_body_classes( $classes ) {
    // Adds a class of group-blog to blogs with more than 1 published author.
    if ( is_multi_author() ) {
        $classes[] = 'gridbone-group-blog';
    }

    if ( !(gridbone_get_option('disable_loading_animation')) ) {
        $classes[] = 'gridbone-animated gridbone-fadein';
    }

    $classes[] = 'gridbone-theme-is-active';

    if ( get_header_image() ) {
        $classes[] = 'gridbone-header-image-active';
    }

    if ( gridbone_get_option('header_image_cover') ) {
        $classes[] = 'gridbone-header-image-cover';
    }

    if ( has_custom_logo() ) {
        $classes[] = 'gridbone-custom-logo-active';
    }

    $classes[] = 'gridbone-layout-type-full';

    if ( is_singular() ) {
        if( is_single() ) {
            if ( gridbone_get_option('featured_media_under_post_title') ) {
                $classes[] = 'gridbone-single-media-under-title';
            }
        }
        if( is_page() ) {
            if ( gridbone_get_option('featured_media_under_page_title') ) {
                $classes[] = 'gridbone-single-media-under-title';
            }
        }

        if ( is_page_template( array( 'template-full-width-page.php', 'template-full-width-post.php' ) ) ) {
           $classes[] = 'gridbone-layout-full-width';
        } else {
            $classes[] = 'gridbone-layout-c-s1';
        }
    } else {
        $classes[] = 'gridbone-layout-full-width';
    }

    $classes[] = 'gridbone-header-style-logo-search-social';

    if ( gridbone_get_option('hide_tagline') ) {
        $classes[] = 'gridbone-tagline-inactive';
    }

    if ( 'beside-title' === gridbone_get_option('logo_location') ) {
        $classes[] = 'gridbone-logo-beside-title';
    } elseif ( 'above-title' === gridbone_get_option('logo_location') ) {
        $classes[] = 'gridbone-logo-above-title';
    } else {
        $classes[] = 'gridbone-logo-above-title';
    }

    if ( gridbone_is_primary_menu_active() ) {
        $classes[] = 'gridbone-primary-menu-active';
    } else {
        $classes[] = 'gridbone-primary-menu-inactive';
    }
    $classes[] = 'gridbone-primary-mobile-menu-active';
    if ( gridbone_get_option('center_primary_menu') ) {
        $classes[] = 'gridbone-primary-menu-centered';
    }

    if ( gridbone_is_secondary_menu_active() ) {
        $classes[] = 'gridbone-secondary-menu-active';
    } else {
        $classes[] = 'gridbone-secondary-menu-inactive';
    }
    $classes[] = 'gridbone-secondary-mobile-menu-active';
    if ( gridbone_get_option('center_secondary_menu') ) {
        $classes[] = 'gridbone-secondary-menu-centered';
    }

    if ( 'before-header' === gridbone_secondary_menu_location() ) {
        $classes[] = 'gridbone-secondary-menu-before-header';
    } elseif ( 'after-header' === gridbone_secondary_menu_location() ) {
        $classes[] = 'gridbone-secondary-menu-after-header';
    } elseif ( 'before-footer' === gridbone_secondary_menu_location() ) {
        $classes[] = 'gridbone-secondary-menu-before-footer';
    } elseif ( 'after-footer' === gridbone_secondary_menu_location() ) {
        $classes[] = 'gridbone-secondary-menu-after-footer';
    } else {
        $classes[] = 'gridbone-secondary-menu-before-header';
    }

    if ( 'top' === gridbone_grid_thumb_position() ) {
        $classes[] = 'gridbone-grid-post-thumbnail-position-top';
    } elseif ( 'bottom' === gridbone_grid_thumb_position() ) {
        $classes[] = 'gridbone-grid-post-thumbnail-position-bottom';
    } elseif ( 'left' === gridbone_grid_thumb_position() ) {
        $classes[] = 'gridbone-grid-post-thumbnail-position-left';
    } elseif ( 'right' === gridbone_grid_thumb_position() ) {
        $classes[] = 'gridbone-grid-post-thumbnail-position-right';
    } elseif ( 'center' === gridbone_grid_thumb_position() ) {
        $classes[] = 'gridbone-grid-post-thumbnail-position-center';
    } elseif ( 'initial' === gridbone_grid_thumb_position() ) {
        $classes[] = 'gridbone-grid-post-thumbnail-position-initial';
    } else {
        $classes[] = 'gridbone-grid-post-thumbnail-position-top';
    }

    if ( 'always-show' === gridbone_grid_title_style() ) {
        $classes[] = 'gridbone-grid-titles-always-show';
    } elseif ( 'hover-show' === gridbone_grid_title_style() ) {
        $classes[] = 'gridbone-grid-titles-hover-show';
    } elseif ( 'hover-hide' === gridbone_grid_title_style() ) {
        $classes[] = 'gridbone-grid-titles-hover-hide';
    } elseif ( 'always-hide' === gridbone_grid_title_style() ) {
        $classes[] = 'gridbone-grid-titles-always-hide';
    } else {
        $classes[] = 'gridbone-grid-titles-always-show';
    }

    if ( gridbone_get_option('center_slide_content') ) {
        $classes[] = 'gridbone-centered-slider';
    } else {
        $classes[] = 'gridbone-no-centered-slider';
    }

    if ( gridbone_is_social_buttons_active() ) {
        $classes[] = 'gridbone-social-buttons-active';
    } else {
        $classes[] = 'gridbone-social-buttons-inactive';
    }

    if ( !(gridbone_get_option('disable_table_colors')) ) {
        $classes[] = 'gridbone-table-css-active';
    }

    if ( gridbone_get_option('auto_width_thumbnail') ) {
        $classes[] = 'gridbone-auto-width-thumbnail';
    } else {
        $classes[] = 'gridbone-full-width-thumbnail';
    }

    if ( gridbone_get_option('remove_grid_item_borders') ) {
        $classes[] = 'gridbone-borderless-grid-items';
    }

    if ( gridbone_is_header_notice_active() && gridbone_header_notice_text() ) {
        if ( gridbone_get_option('no_center_header_notice') ) {
            $classes[] = 'gridbone-no-centered-header-notice';
        } else {
            $classes[] = 'gridbone-centered-header-notice';
        }
    }

    if ( gridbone_is_footer_notice_active() && gridbone_footer_notice_text() ) {
        if ( gridbone_get_option('no_center_footer_notice') ) {
            $classes[] = 'gridbone-no-centered-footer-notice';
        } else {
            $classes[] = 'gridbone-centered-footer-notice';
        }
    }

    if ( is_singular() ) {
        if ( gridbone_get_option('no_center_post_ad_one') ) {
            $classes[] = 'gridbone-no-centered-post-ad-one';
        } else {
            $classes[] = 'gridbone-centered-post-ad-one';
        }

        if ( gridbone_get_option('no_center_post_ad_two') ) {
            $classes[] = 'gridbone-no-centered-post-ad-two';
        } else {
            $classes[] = 'gridbone-centered-post-ad-two';
        }
    }

    if ( gridbone_is_header_content_image_active() ) {
        $classes[] = 'gridbone-header-content-image-active';
    }

    if ( gridbone_is_footer_content_image_active() ) {
        $classes[] = 'gridbone-footer-content-image-active';
    }

    if ( gridbone_get_option('no_underline_content_links') ) {
        $classes[] = 'gridbone-nouc-links';
    } else {
        $classes[] = 'gridbone-uc-links';
    }

    return apply_filters( 'gridbone_body_classes', $classes );
}
add_filter( 'body_class', 'gridbone_body_classes' );


/**
* More Custom Functions
*/

// Change excerpt length
function gridbone_excerpt_length($length) {
    if ( is_admin() ) {
        return $length;
    }
    $read_more_length = 17;
    if ( gridbone_get_option('read_more_length') ) {
        $read_more_length = gridbone_get_option('read_more_length');
    }
    return apply_filters( 'gridbone_excerpt_length', $read_more_length );
}
add_filter('excerpt_length', 'gridbone_excerpt_length');

// Change excerpt more word
function gridbone_excerpt_more($more) {
    if ( is_admin() ) {
        return $more;
    }
    return apply_filters( 'gridbone_excerpt_more', '...' );
}
add_filter('excerpt_more', 'gridbone_excerpt_more');

function gridbone_grid_post_title_length() {
    $grid_title_length = 6;
    if ( gridbone_get_option('grid_title_length') ) {
        $grid_title_length = gridbone_get_option('grid_title_length');
    }
    return apply_filters( 'gridbone_grid_post_title_length', $grid_title_length );
}

if ( ! function_exists( 'wp_body_open' ) ) :
    /**
     * Fire the wp_body_open action.
     *
     * Added for backwards compatibility to support pre 5.2.0 WordPress versions.
     */
    function wp_body_open() { // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedFunctionFound
        /**
         * Triggered after the opening <body> tag.
         */
        do_action( 'wp_body_open' ); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
    }
endif;

function gridbone_post_ad_one() {
    global $post;
    $adcode = '';
    if ( gridbone_get_option('post_ad_one_code') ) {
        $adcode = gridbone_get_option('post_ad_one_code');
    }
    if ( gridbone_get_option('enable_post_ad_one') ) {
        if(!empty($adcode)) { ?>
            <div class="gridbone-post-ad-one"><div class="gridbone-post-ad-one-inside"><?php echo do_shortcode($adcode); ?></div></div>
        <?php }
    }
}

function gridbone_post_ad_two() {
    global $post;
    $adcode = '';
    if ( gridbone_get_option('post_ad_two_code') ) {
        $adcode = gridbone_get_option('post_ad_two_code');
    }
    if ( gridbone_get_option('enable_post_ad_two') ) {
        if(!empty($adcode)) { ?>
            <div class="gridbone-post-ad-two"><div class="gridbone-post-ad-two-inside"><?php echo do_shortcode($adcode); ?></div></div>
        <?php }
    }
}

function gridbone_search_box_placeholder_text() {
    $placeholder_text = esc_html__( 'Enter your search keyword...', 'gridbone' );
    if ( gridbone_get_option('search_box_placeholder_text') ) {
        $placeholder_text = gridbone_get_option('search_box_placeholder_text');
    }
    return apply_filters( 'gridbone_search_box_placeholder_text', $placeholder_text );
}


/**
* Custom Hooks
*/

function gridbone_before_header() {
    do_action('gridbone_before_header');
}

function gridbone_after_header() {
    do_action('gridbone_after_header');
}

function gridbone_before_slider() {
    do_action('gridbone_before_slider');
}

function gridbone_after_slider() {
    do_action('gridbone_after_slider');
}

function gridbone_before_main_content() {
    do_action('gridbone_before_main_content');
}
add_action('gridbone_before_main_content', 'gridbone_top_widgets', 20 );
add_action('gridbone_before_main_content', 'gridbone_top_left_right_widgets', 40 );

function gridbone_after_main_content() {
    do_action('gridbone_after_main_content');
}
add_action('gridbone_after_main_content', 'gridbone_bottom_widgets', 10 );

function gridbone_sidebar_one() {
    do_action('gridbone_sidebar_one');
}
add_action('gridbone_sidebar_one', 'gridbone_sidebar_one_widgets', 10 );

function gridbone_before_single_post() {
    do_action('gridbone_before_single_post');
}

function gridbone_before_single_post_title() {
    do_action('gridbone_before_single_post_title');
}

function gridbone_after_single_post_title() {
    do_action('gridbone_after_single_post_title');
}
add_action('gridbone_after_single_post_title', 'gridbone_post_ad_one', 50 );

function gridbone_top_single_post_content() {
    do_action('gridbone_top_single_post_content');
}

function gridbone_bottom_single_post_content() {
    do_action('gridbone_bottom_single_post_content');
}

function gridbone_after_single_post_content() {
    do_action('gridbone_after_single_post_content');
}
add_action('gridbone_after_single_post_content', 'gridbone_post_ad_two', 50 );

function gridbone_after_single_post() {
    do_action('gridbone_after_single_post');
}

function gridbone_before_single_page() {
    do_action('gridbone_before_single_page');
}

function gridbone_before_single_page_title() {
    do_action('gridbone_before_single_page_title');
}

function gridbone_after_single_page_title() {
    do_action('gridbone_after_single_page_title');
}

function gridbone_after_single_page_content() {
    do_action('gridbone_after_single_page_content');
}

function gridbone_after_single_page() {
    do_action('gridbone_after_single_page');
}

function gridbone_before_comments() {
    do_action('gridbone_before_comments');
}

function gridbone_after_comments() {
    do_action('gridbone_after_comments');
}

function gridbone_before_footer() {
    do_action('gridbone_before_footer');
}

function gridbone_after_footer() {
    do_action('gridbone_after_footer');
}

function gridbone_before_nongrid_post_title() {
    do_action('gridbone_before_nongrid_post_title');
}

function gridbone_after_nongrid_post_title() {
    do_action('gridbone_after_nongrid_post_title');
}

if ( !(gridbone_get_option('enable_widgets_block_editor')) ) {
    // Disables the block editor from managing widgets in the Gutenberg plugin.
    add_filter( 'gutenberg_use_widgets_block_editor', '__return_false', 100 );

    // Disables the block editor from managing widgets.
    add_filter( 'use_widgets_block_editor', '__return_false' );
}

if ( ! function_exists( 'gridbone_remove_theme_support' ) ) :
function gridbone_remove_theme_support() {

    if ( gridbone_is_fitvids_active() ) {
        // Remove responsive embedded content support.
        remove_theme_support( 'responsive-embeds' );
    }

}
endif;
add_action( 'after_setup_theme', 'gridbone_remove_theme_support', 1000 );


/**
* Media functions
*/

if ( ! function_exists( 'gridbone_grid_data' ) ) :
function gridbone_grid_data() { ?>
    <?php global $post; ?>
    <?php if ( !(gridbone_get_option('hide_grid_title')) ) { ?>
    <div class="gridbone-thumbnail-overlay gridbone-clearfix">
    <div class="gridbone-thumbnail-overlay-inside gridbone-clearfix">
        <?php if ( gridbone_get_option('limit_grid_titles') ) { ?>
            <div class="gridbone-grid-post-header gridbone-clearfix"><h3 class="gridbone-grid-post-title"><?php echo esc_html( wp_trim_words( get_the_title(), gridbone_grid_post_title_length(), '...' ) ); ?></h3></div>
        <?php } else { ?>
            <div class="gridbone-grid-post-header gridbone-clearfix"><?php the_title( '<h3 class="gridbone-grid-post-title">', '</h3>' ); ?></div>
        <?php } ?>
    </div>
    </div>
    <?php } ?>
<?php }
endif;

function gridbone_media_content_grid() {
    global $post; ?>

    <?php if ( has_post_thumbnail($post->ID) ) { ?>
    <div class="gridbone-grid-post-thumbnail">
        <?php if ( gridbone_get_option('grid_link_disable') ) { ?>
            <?php the_post_thumbnail('gridbone-125w-125h-image', array('class' => 'gridbone-grid-post-thumbnail-img', 'title' => the_title_attribute('echo=0'))); ?>
            <?php gridbone_grid_data(); ?>
        <?php } else { ?>
            <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" class="gridbone-grid-post-thumbnail-link">
            <?php the_post_thumbnail('gridbone-125w-125h-image', array('class' => 'gridbone-grid-post-thumbnail-img', 'title' => the_title_attribute('echo=0'))); ?>
            <?php gridbone_grid_data(); ?>
            </a>
        <?php } ?>
    </div>
    <?php } else { ?>
    <div class="gridbone-grid-post-thumbnail gridbone-grid-post-thumbnail-default">
        <?php if ( gridbone_get_option('grid_link_disable') ) { ?>
            <img src="<?php echo esc_url( get_template_directory_uri() . '/assets/images/no-image-125-125.png' ); ?>" class="gridbone-grid-post-thumbnail-img"/>
            <?php gridbone_grid_data(); ?>
        <?php } else { ?>
            <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" class="gridbone-grid-post-thumbnail-link">
            <img src="<?php echo esc_url( get_template_directory_uri() . '/assets/images/no-image-125-125.png' ); ?>" class="gridbone-grid-post-thumbnail-img"/>
            <?php gridbone_grid_data(); ?>
            </a>
        <?php } ?>
    </div>
    <?php } ?>

<?php }

function gridbone_media_content_single() {
    global $post;
    if ( has_post_thumbnail($post->ID) ) {
        if ( !(gridbone_get_option('hide_thumbnail')) ) {
            if ( gridbone_get_option('thumbnail_link') == 'no' ) { ?>
                <div class="gridbone-post-thumbnail-single">
                <?php
                if ( is_page_template( array( 'template-full-width-post.php' ) ) ) {
                    the_post_thumbnail('gridbone-1200w-autoh-image', array('class' => 'gridbone-post-thumbnail-single-img', 'title' => the_title_attribute('echo=0')));
                } else {
                    the_post_thumbnail('gridbone-872w-autoh-image', array('class' => 'gridbone-post-thumbnail-single-img', 'title' => the_title_attribute('echo=0')));
                }
                ?>
                </div>
            <?php } else { ?>
                <div class="gridbone-post-thumbnail-single">
                <?php if ( is_page_template( array( 'template-full-width-post.php' ) ) ) { ?>
                    <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" title="<?php /* translators: %s: post title. */ echo esc_attr( sprintf( __( 'Permanent Link to %s', 'gridbone' ), the_title_attribute( 'echo=0' ) ) ); ?>" class="gridbone-post-thumbnail-single-link"><?php the_post_thumbnail('gridbone-1200w-autoh-image', array('class' => 'gridbone-post-thumbnail-single-img', 'title' => the_title_attribute('echo=0'))); ?></a>
                <?php } else { ?>
                    <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" title="<?php /* translators: %s: post title. */ echo esc_attr( sprintf( __( 'Permanent Link to %s', 'gridbone' ), the_title_attribute( 'echo=0' ) ) ); ?>" class="gridbone-post-thumbnail-single-link"><?php the_post_thumbnail('gridbone-872w-autoh-image', array('class' => 'gridbone-post-thumbnail-single-img', 'title' => the_title_attribute('echo=0'))); ?></a>
                <?php } ?>
                </div>
    <?php   }
        }
    }
}

function gridbone_media_content_single_location() {
    global $post;
    if( gridbone_get_option('featured_media_under_post_title') ) {
        add_action('gridbone_after_single_post_title', 'gridbone_media_content_single', 10 );
    } else {
        add_action('gridbone_before_single_post_title', 'gridbone_media_content_single', 10 );
    }
}
add_action('template_redirect', 'gridbone_media_content_single_location', 100 );

function gridbone_media_content_page() {
    global $post; ?>
    <?php
    if ( has_post_thumbnail($post->ID) ) {
        if ( !(gridbone_get_option('hide_page_thumbnail')) ) {
            if ( gridbone_get_option('thumbnail_link_page') == 'no' ) { ?>
                <div class="gridbone-post-thumbnail-single">
                <?php
                if ( is_page_template( array( 'template-full-width-page.php' ) ) ) {
                    the_post_thumbnail('gridbone-1200w-autoh-image', array('class' => 'gridbone-post-thumbnail-single-img', 'title' => the_title_attribute('echo=0')));
                } else {
                    the_post_thumbnail('gridbone-872w-autoh-image', array('class' => 'gridbone-post-thumbnail-single-img', 'title' => the_title_attribute('echo=0')));
                }
                ?>
                </div>
            <?php } else { ?>
                <div class="gridbone-post-thumbnail-single">
                <?php if ( is_page_template( array( 'template-full-width-page.php' ) ) ) { ?>
                    <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" title="<?php /* translators: %s: post title. */ echo esc_attr( sprintf( __( 'Permanent Link to %s', 'gridbone' ), the_title_attribute( 'echo=0' ) ) ); ?>" class="gridbone-post-thumbnail-single-link"><?php the_post_thumbnail('gridbone-1200w-autoh-image', array('class' => 'gridbone-post-thumbnail-single-img', 'title' => the_title_attribute('echo=0'))); ?></a>
                <?php } else { ?>
                    <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" title="<?php /* translators: %s: post title. */ echo esc_attr( sprintf( __( 'Permanent Link to %s', 'gridbone' ), the_title_attribute( 'echo=0' ) ) ); ?>" class="gridbone-post-thumbnail-single-link"><?php the_post_thumbnail('gridbone-872w-autoh-image', array('class' => 'gridbone-post-thumbnail-single-img', 'title' => the_title_attribute('echo=0'))); ?></a>
                <?php } ?>
                </div>
    <?php   }
        }
    }
    ?>
<?php }

function gridbone_media_content_page_location() {
    global $post;
    if( gridbone_get_option('featured_media_under_page_title') ) {
        add_action('gridbone_after_single_page_title', 'gridbone_media_content_page', 10 );
    } else {
        add_action('gridbone_before_single_page_title', 'gridbone_media_content_page', 10 );
    }
}
add_action('template_redirect', 'gridbone_media_content_page_location', 110 );


/**
* Enqueue scripts and styles
*/

function gridbone_scripts() {
    wp_enqueue_style('gridbone-maincss', get_stylesheet_uri(), array(), null);
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), null );
    wp_enqueue_style('gridbone-webfont', '//fonts.googleapis.com/css?family=Roboto+Slab:400,700|Oswald:400,700|Frank+Ruhl+Libre:400,700|Battambang:400,700&amp;display=swap', array(), null);

    $gridbone_primary_menu_active = false;
    if ( gridbone_is_primary_menu_active() ) {
        $gridbone_primary_menu_active = true;
    }
    $gridbone_secondary_menu_active = false;
    if ( gridbone_is_secondary_menu_active() ) {
        $gridbone_secondary_menu_active = true;
    }

    $gridbone_sticky_menu_active = false;
    $gridbone_sticky_mobile_menu_active = false;
    if ( gridbone_is_sticky_menu_active() ) {
        $gridbone_sticky_menu_active = true;
    }
    if ( gridbone_is_sticky_mobile_menu_active() ) {
        $gridbone_sticky_mobile_menu_active = true;
    }

    $gridbone_fitvids_active = false;
    if ( gridbone_is_fitvids_active() ) {
        $gridbone_fitvids_active = true;
    }
    if ( $gridbone_fitvids_active ) {
        wp_enqueue_script('fitvids', get_template_directory_uri() .'/assets/js/jquery.fitvids.min.js', array( 'jquery' ), null, true);
    }

    $gridbone_backtotop_active = false;
    if ( gridbone_is_backtotop_active() ) {
        $gridbone_backtotop_active = true;
    }

    $gridbone_sticky_sidebar_active = false;
    if ( gridbone_is_sticky_sidebar_active() ) {
        $gridbone_sticky_sidebar_active = true;
    }
    if ( is_singular() ) {
        if ( is_page_template( array( 'template-full-width-page.php', 'template-full-width-post.php' ) ) ) {
           $gridbone_sticky_sidebar_active = false;
        }
    } else {
        $gridbone_sticky_sidebar_active = false;
    }
    if ( $gridbone_sticky_sidebar_active ) {
        wp_enqueue_script('ResizeSensor', get_template_directory_uri() .'/assets/js/ResizeSensor.min.js', array( 'jquery' ), null, true);
        wp_enqueue_script('theia-sticky-sidebar', get_template_directory_uri() .'/assets/js/theia-sticky-sidebar.min.js', array( 'jquery' ), null, true);
    }

    $gridbone_slider_active = false;
    if ( gridbone_is_slider_active() ) {
        if ( 'front-page' === gridbone_get_option('slider_display') ) {
            if ( is_front_page() && is_home() && !is_paged() ) {
                $gridbone_slider_active = true;
            }
        } elseif ( 'front-page-static' === gridbone_get_option('slider_display') ) {
            if ( is_front_page() && is_singular() ) {
                $gridbone_slider_active = true;
            }
        } elseif ( 'blog-posts-index' === gridbone_get_option('slider_display') ) {
            if ( is_home() && !is_paged() ) {
                $gridbone_slider_active = true;
            }
        } elseif ( 'everywhere' === gridbone_get_option('slider_display') ) {
                $gridbone_slider_active = true;
        } else {
            if ( is_front_page() && is_home() && !is_paged() ) {
                $gridbone_slider_active = true;
            }
        }
    }
    if ( $gridbone_slider_active ) {
        wp_enqueue_style('owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.min.css', array(), null );
        wp_enqueue_script('owl-carousel', get_template_directory_uri() .'/assets/js/owl.carousel.min.js', array( 'jquery', 'imagesloaded' ), null, true);
    }

    $gridbone_slider_autoplay = false;
    if ( gridbone_get_option('slider_autoplay') ) {
        $gridbone_slider_autoplay = true;
    }
    $gridbone_slider_loop = false;
    if ( gridbone_get_option('slider_loop') ) {
        $gridbone_slider_loop = true;
    }
    $gridbone_slider_autoplayhoverpause = false;
    if ( gridbone_get_option('slider_autoplayhoverpause') ) {
        $gridbone_slider_autoplayhoverpause = true;
    }
    $gridbone_slider_autoplaytimeout = 1000;
    if ( gridbone_get_option('slider_autoplaytimeout') ) {
        $gridbone_slider_autoplaytimeout = gridbone_get_option('slider_autoplaytimeout');
    }
    $gridbone_slider_autoplayspeed = 200;
    if ( gridbone_get_option('slider_autoplayspeed') ) {
        $gridbone_slider_autoplayspeed = gridbone_get_option('slider_autoplayspeed');
    }
    $gridbone_show_dots_pagination = false;
    if ( gridbone_get_option('show_dots_pagination') ) {
        $gridbone_show_dots_pagination = true;
    }
    $gridbone_show_next_prev_navigation = true;
    if ( gridbone_get_option('hide_next_prev_navigation') ) {
        $gridbone_show_next_prev_navigation = false;
    }

    $gridbone_autoheight_active = false;
    if ( gridbone_get_option('enable_autoheight') ) {
        $gridbone_autoheight_active = true;
    }

    $gridbone_slider_rtl = false;
    if ( is_rtl() ) {
        $gridbone_slider_rtl = true;
    }




    wp_enqueue_script('gridbone-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), null, true );
    wp_enqueue_script('gridbone-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), null, true );
    wp_enqueue_script('gridbone-customjs', get_template_directory_uri() .'/assets/js/custom.js', array( 'jquery', 'imagesloaded' ), null, true);

    wp_localize_script( 'gridbone-customjs', 'gridbone_ajax_object',
        array(
            'ajaxurl' => esc_url_raw( admin_url( 'admin-ajax.php' ) ),
            'primary_menu_active' => $gridbone_primary_menu_active,
            'secondary_menu_active' => $gridbone_secondary_menu_active,
            'sticky_menu_active' => $gridbone_sticky_menu_active,
            'sticky_mobile_menu_active' => $gridbone_sticky_mobile_menu_active,
            'sticky_sidebar_active' => $gridbone_sticky_sidebar_active,

            'slider_active' => $gridbone_slider_active,
            'slider_autoplay' => $gridbone_slider_autoplay,
            'slider_loop' => $gridbone_slider_loop,
            'slider_autoplayhoverpause' => $gridbone_slider_autoplayhoverpause,
            'slider_autoplaytimeout' => $gridbone_slider_autoplaytimeout,
            'slider_autoplayspeed' => $gridbone_slider_autoplayspeed,
            'show_dots_pagination' => $gridbone_show_dots_pagination,
            'show_next_prev_navigation' => $gridbone_show_next_prev_navigation,
            'autoheight_active' => $gridbone_autoheight_active,
            'slider_rtl' => $gridbone_slider_rtl,
            'fitvids_active' => $gridbone_fitvids_active,
            'backtotop_active' => $gridbone_backtotop_active,
        )
    );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    wp_enqueue_script('gridbone-html5shiv-js', get_template_directory_uri() .'/assets/js/html5shiv.js', array('jquery'), null, true);

    wp_localize_script('gridbone-html5shiv-js','gridbone_custom_script_vars',array(
        'elements_name' => esc_html__('abbr article aside audio bdi canvas data datalist details dialog figcaption figure footer header hgroup main mark meter nav output picture progress section summary template time video', 'gridbone'),
    ));
}
add_action( 'wp_enqueue_scripts', 'gridbone_scripts' );

/**
 * Enqueue IE compatible scripts and styles.
 */
function gridbone_ie_scripts() {
    wp_enqueue_script( 'respond', get_template_directory_uri(). '/assets/js/respond.min.js', array(), null, false );
    wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'gridbone_ie_scripts' );

/**
 * Enqueue styles for the block-based editor.
 */
function gridbone_block_editor_styles() {
    wp_enqueue_style( 'gridbone-block-editor-style', get_template_directory_uri() . '/assets/css/editor-blocks.css', array(), null );
}
add_action( 'enqueue_block_editor_assets', 'gridbone_block_editor_styles' );

/**
 * Enqueue customizer styles.
 */
function gridbone_enqueue_customizer_styles() {
    wp_enqueue_style( 'gridbone-customizer-styles', get_template_directory_uri() . '/assets/css/customizer-style.css', array(), null );
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), null );
}
add_action( 'customize_controls_enqueue_scripts', 'gridbone_enqueue_customizer_styles' );


/**
* Block Styles
*/

/**
 * Register Custom Block Styles
 */
if ( function_exists( 'register_block_style' ) ) :
    function gridbone_register_block_styles() {

        /**
         * Register block style
         */
        register_block_style( 'core/button', array( 'name' => 'gridbone-button', 'label' => __( 'GridBone Button', 'gridbone' ), 'is_default' => true, 'style_handle' => 'gridbone-maincss', ) ); // phpcs:ignore WPThemeReview.PluginTerritory.ForbiddenFunctions.editor_blocks_register_block_style

    }
    add_action( 'init', 'gridbone_register_block_styles' );
endif;


/**
* Customizer Options
*/

function gridbone_inline_css() {
    $custom_css = '';

    if ( !(gridbone_is_backtotop_active()) ) {
        $custom_css .= '.gridbone-scroll-top{display:none !important;}';
    }

    if ( gridbone_get_option('header_image_title_mobile') ) {
        $custom_css .= '.gridbone-header-image .gridbone-header-image-info{display:block !important;}';
        $custom_css .= '.gridbone-header-image .gridbone-header-image-info .gridbone-header-image-site-title{display:block !important;}';
    }

    if ( gridbone_get_option('header_image_description_mobile') ) {
        $custom_css .= '.gridbone-header-image .gridbone-header-image-info{display:block !important;}';
        $custom_css .= '.gridbone-header-image .gridbone-header-image-info .gridbone-header-image-site-description{display:block !important;}';
    }

    if ( gridbone_get_option('header_image_cover') ) {
        if ( gridbone_get_option('header_image_height_mobile') ) {
            $custom_css .= '@media screen and (max-width: 599px){.gridbone-header-image-cover .gridbone-header-img{min-height:'.esc_html( gridbone_get_option('header_image_height_mobile') ).';}}';
        }
    }
    if ( gridbone_get_option('header_padding') ) {
        $custom_css .= '.gridbone-header-inside-content{padding:'.esc_html( gridbone_get_option('header_padding') ).';}';
    }

    if ( gridbone_get_option('limit_logo_width') ) {
        if ( gridbone_logo_max_width() ) {
            $custom_css .= '.gridbone-logo-img{max-width:'.esc_html( gridbone_logo_max_width() ).';}';
        }
    }

    if ( gridbone_grid_item_border_radius() ) {
        $custom_css .= '.gridbone-posts-grid .gridbone-grid-post{-webkit-border-radius:'.esc_html( gridbone_grid_item_border_radius() ).';-moz-border-radius:'.esc_html( gridbone_grid_item_border_radius() ).';border-radius:'.esc_html( gridbone_grid_item_border_radius() ).';}';
        $custom_css .= '.gridbone-posts-grid .gridbone-grid-post .gridbone-grid-post-inside{-webkit-border-radius:'.esc_html( gridbone_grid_item_border_radius() ).';-moz-border-radius:'.esc_html( gridbone_grid_item_border_radius() ).';border-radius:'.esc_html( gridbone_grid_item_border_radius() ).';}';
    }

    $header_content_bg_size = 'cover';
    if ( gridbone_get_option('header_content_bg_size') ) {
        $header_content_bg_size = gridbone_get_option('header_content_bg_size');
    }

    $header_content_bg_position = 'center top';
    if ( gridbone_get_option('header_content_bg_position') ) {
        $header_content_bg_position = gridbone_get_option('header_content_bg_position');
    }

    $header_content_bg_attachment = 'scroll';
    if ( gridbone_get_option('header_content_bg_attachment') ) {
        $header_content_bg_attachment = gridbone_get_option('header_content_bg_attachment');
    }

    $header_content_bg_repeat = 'no-repeat';
    if ( gridbone_get_option('header_content_bg_repeat') ) {
        $header_content_bg_repeat = gridbone_get_option('header_content_bg_repeat');
    }

    $header_image_id = 0;
    if ( gridbone_get_option('header_content_image') ) {
        $header_image_id = absint(gridbone_get_option('header_content_image'));
    }
    if ( $header_image_id > 0 ) {
        $custom_css .= '.gridbone-header-inside{background-image:url("'.esc_url( wp_get_attachment_url( $header_image_id ) ).'");background-position:'.esc_html( $header_content_bg_position ).';background-attachment:'.esc_html( $header_content_bg_attachment ).';background-repeat:'.esc_html( $header_content_bg_repeat ).';-webkit-background-size:'.esc_html( $header_content_bg_size ).';-moz-background-size:'.esc_html( $header_content_bg_size ).';-o-background-size:'.esc_html( $header_content_bg_size ).';background-size:'.esc_html( $header_content_bg_size ).';}';
    }

    $footer_content_bg_size = 'cover';
    if ( gridbone_get_option('footer_content_bg_size') ) {
        $footer_content_bg_size = gridbone_get_option('footer_content_bg_size');
    }

    $footer_content_bg_position = 'center top';
    if ( gridbone_get_option('footer_content_bg_position') ) {
        $footer_content_bg_position = gridbone_get_option('footer_content_bg_position');
    }

    $footer_content_bg_attachment = 'scroll';
    if ( gridbone_get_option('footer_content_bg_attachment') ) {
        $footer_content_bg_attachment = gridbone_get_option('footer_content_bg_attachment');
    }

    $footer_content_bg_repeat = 'no-repeat';
    if ( gridbone_get_option('footer_content_bg_repeat') ) {
        $footer_content_bg_repeat = gridbone_get_option('footer_content_bg_repeat');
    }

    $footer_image_id = 0;
    if ( gridbone_get_option('footer_content_image') ) {
        $footer_image_id = absint(gridbone_get_option('footer_content_image'));
    }
    if ( $footer_image_id > 0 ) {
        $custom_css .= '#gridbone-footer-blocks{background-image:url("'.esc_url( wp_get_attachment_url( $footer_image_id ) ).'");background-position:'.esc_html( $footer_content_bg_position ).';background-attachment:'.esc_html( $footer_content_bg_attachment ).';background-repeat:'.esc_html( $footer_content_bg_repeat ).';-webkit-background-size:'.esc_html( $footer_content_bg_size ).';-moz-background-size:'.esc_html( $footer_content_bg_size ).';-o-background-size:'.esc_html( $footer_content_bg_size ).';background-size:'.esc_html( $footer_content_bg_size ).';}';
        $custom_css .= '#gridbone-footer-blocks .widget li{border:none !important;}';
    }

    if( '' != $custom_css ) {
        wp_add_inline_style( 'gridbone-maincss', $custom_css );
    }
}
add_action( 'wp_enqueue_scripts', 'gridbone_inline_css' );


// Header styles
if ( ! function_exists( 'gridbone_header_style' ) ) :
function gridbone_header_style() {
    $header_text_color = get_header_textcolor();
    //if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) { return; }
    ?>
    <style type="text/css">
    <?php if ( ! display_header_text() ) : ?>
        .gridbone-site-title, .gridbone-site-description {position: absolute;clip: rect(1px, 1px, 1px, 1px);}
    <?php else : ?>
        .gridbone-site-title, .gridbone-site-title a, .gridbone-site-description {color: #<?php echo esc_attr( $header_text_color ); ?>;}
    <?php endif; ?>
    </style>
    <?php
}
endif;